/**
 * The HeartyMeal class represents a meal that can be consumed by the kobold,
 * which increases its statuses.
 */
function Sandwich() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Sandwich";
    var itemDescription = "A ham-sandwich. With butter. Yummy.";
    var baseValue = 4;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You tear into the sandwich, biting off nearly half of it in one go.
                            The butter tastes surprisingly [b]good[/b].
                            You suspect it was hand-made.
                            The ham, while pretty good itself, pales in comparison.
                            The entire thing ends up tasting pretty darn great!
                        [/p]
                        [p]
                            You eagerly chomp down again and again, but sadly the entire thing is gone before you manage to sate your hunger completely.
                            You lick your fingers clean of any residual crumbs and a smidgen of butter that had escaped the bread.
                            That was quite an excellent pick-me-up!
                            Much better than what you [i]usually[/i] eat, and far more nutritional to boot.
                            You feel energized and ready for more adventure!
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.SANDWICH;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(6, "Ate a sandwich");
        global.kobold.status.mental.increase(6, "Ate a sandwich");
        global.kobold.status.stamina.increase(6, "Ate a sandwich");
        global.kobold.status.exertion.decrease(6, "Ate a sandwich");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +6), 
            new Change("Food", "Sanity", +6),
            new Change("Food", "Stamina", +6),
            new Change("Food", "Sexual exhaustion", -6, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
