/**
 * The EnduGain class represents a potion that can be consumed by the kobold,
 * which increases its endurance, but lowers its charisma.
 */
function EnduGain() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "EnduGain Potion";
    var itemDescription = `A glass bottle filled to the brim with a disgusting-looking brownish slop.
                           Promises to make you more enduring.`;
    var baseValue = 25;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion.
                            It smells as bad as it looks.
                            Hoping this isn't some kind of liquid waste, you bring the vial to your lips, close your eyes and chug down.
                        [/p]
                        [p]
                            It tastes [b]horrible[/b].
                            Definitely some kind of [b]sewage water[/b].
                            Almost throwing up the moment the first bit of the vile liquid splashes atop your tongue,
                            you seriously consider [b]not[/b] finishing the potion.
                            But you want your [b]endurance[/b], damnit.
                            Zoning out your mind as best you can, you chug down the entire thing, ending in a revolting [b]burp[/b] that makes your stomach churn.
                        [/p]
                        [p]
                            Despite going through that [b]torture[/b], you don't feel stronger in any way.
                            If anything, your breath has been sullied by the filthy potion, making people like you less in the future.
                            Was this a bad move?
                        [/p]
                        [p]
                            Then it hits you.
                            You've [i]endured[/i] drinking the potion.
                            It was more of a [b]mental test[/b] than a physical enhancement.
                            Damnit.
                            Can't those dumb alchemists invent something non-horrible for once?
                        [/p]
                        [p]
                            [b]You have gained 1 endurance.[/b][nl]
                            [warn][b]You have lost 1 charisma.[/b][/warn]
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as enduring as you're ever going to get.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when minned out.
     * @returns {string} The consume popup contents when minned out.
     */
    function buildMinContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are't charismatic enough to convince yourself to drink something that looks this revolting.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.ENDUGAIN;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var end = global.kobold.stats.get(StatsEnum.ENDURANCE);
        var cha = global.kobold.stats.get(StatsEnum.CHARISMA);
        var maxed = (end >= global.kobold.stats.statMax);
        var minned = (cha <= global.kobold.stats.statMin);
        if (maxed) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMaxContents()));
            return false;
        }
        if (minned) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMinContents()));
            return false;
        } else {
            global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
            global.kobold.stats.decreaseStat(StatsEnum.CHARISMA, 1);
            global.ui.showFullscreenPopup(buildPopupContents());
        }
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Potion-stripped} potion A Potion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
