/**
 * Can create the HTML necessary to add images mid-text.
 */
function ImageInText() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sfwClass = "sfw";
    var nsfwClass = "nsfw";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Creates the HTML required for an inline image with link to the full image.
     * @param {type} url The URL of the image. Should contain "m" or "f" or some other gender-specific variable if applicable. Should not contain the "-full" suffix.
     * @param {string} ext The extension of the image. Should not start with a period. Ex.: "png"
     * @param {ImageWidthEnum} width A member of the ImageWidthEnum. CUSTOM means no width will be added, and the customCSS must contain a width.
     * @param {boolean} sfw True if safe for work, false otherwise.
     * @param {string} artist The name of the artist.
     * @param {string} customCSS Custom CSS added to the image. May be omitted.
     * @returns {string} The HTML describing the inline image.
     */
    this.create = function (url, ext, width, sfw, artist, customCSS) {
        var link = `<a href="${url}-full.${ext}" target="_blank">`;
        var image = `<img class="${sfw ? sfwClass : nsfwClass} ${ImageWidthEnum.properties[width]}"`;
        image += `src="${url}.${ext}" title="Made by ${artist}" ${customCSS ? `style="${customCSS}"` : ``}>`;
        return link + image + `</a>`;
    };
}

var ImageWidthEnum = {
    SMALLER: 1,
    SMALL: 2,
    NORMAL: 3,
    MEDIUM: 4,
    WIDE: 5,
    CUSTOM: 99
};

ImageWidthEnum.properties = {
    1: "smallerimage",
    2: "smallimage",
    3: "standardimage",
    4: "mediumimage",
    5: "wideimage",
    99: ""
};
