/**
 * Farmer's maid ending.
 * @param {FarmerMaidController} controller The Varanar, Afternoon Three controller.
 */
function FarmerMaidDrunkDeclineDad(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preDeath;
    var subController = ctrl.death;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new FarmerMaidDrunkDeclineLick(ctrl);
    var secondNext = new FarmerMaidDrunkDeclineBite(ctrl);

    var firstChoice = FarmerMaidDrunkDeclineDadChoice.LICK;
    var secondChoice = FarmerMaidDrunkDeclineDadChoice.BITE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var broom = ctrl.drunk.get() === FarmerMaidDrunkChoice.DECLINE;
        var toReturn = `[p]
                            One day,
                            a broadly built horse walks through the front door, carrying a dire missive.
                            Romeo had an [i]unfortunate accident[/i] while tending to his field.
                            Somehow, he [i]stabbed himself[/i] with his rake, while watering the crops.
                            The circumstances are [b]suspicious[/b], to say the least,
                            but you are reminded these things tend to happen around here.
                            Farming near the hamlet, ironically, is about as dangerous as being a city guard in Varanar.
                            Whether this was a robbery gone wrong, a rival offing your master for personal gains,
                            or an [i]actual[/i] accident, you will never know.
                        [/p]
                        [p]
                            Falco takes the news rather well.
                            He never really saw eye-to-eye with the man of the house.
                            Juliet, however, is devastated.
                            She quickly grows [b]bitter[/b] and [b]cold[/b].
                            On the day of her husband's funeral, she doesn't even bother to show.
                        [/p]
                        [p]
                            Romeo is buried in the backyard by his closest farmer friends.
                            After the emotional burial, Falco confronts you.
                            The bird informs you that your [i]slave contract[/i] technically only bound you to his father.
                            But, the eagle doesn't think you've put enough work in yet to be set free like that.
                            His father paid [b]a lot[/b] of gold for you.
                            He wants to [b]keep you[/b].
                            And he's not taking no for an answer.
                        [/p]
                        [p]
                            You argue with the bird, saying that he can't do this.
                            You're free.
                            He can't keep holding you!
                            But he can.
                            You're a kobold.
                            You have no rights.
                            His mind seems made up.
                            He's taking you back home with him, whether you like it or not.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Run</button>`;

        var tooltip = global.parser.parse(`You [b]must[/b] escape, no matter the cost.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Relent</button>`;

        var tooltip = global.parser.parse(`If you run, he might have his dog hunt you down. You don't want to die.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var FarmerMaidDrunkDeclineDadChoice = {
    LICK: 1,
    BITE: 2
};
