/**
 * Farmer's maid ending.
 * @param {FarmerMaidController} controller The Varanar, Afternoon Three controller.
 */
function FarmerMaidTooFarTell(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = FarmerMaidTooFarChoice.TELL;
    var reqController = ctrl.toofar;
    var subController = ctrl.toofarTell;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new FarmerMaidTooFarFight(ctrl);
    var secondNext = new FarmerMaidTooFarServe(ctrl);

    var firstChoice = FarmerMaidTooFarTellChoice.FIGHT;
    var secondChoice = FarmerMaidTooFarTellChoice.SERVE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You have to go get Romeo, before Juliet gets beaten to death.
                            He's the only one who can put a stop to this.
                            You [b]bolt[/b] out the backdoor,
                            and sprint into the neighbouring farmland, which the human is tilling.
                            He notices your speedy approach, responding quite calmly.
                            "[color=red]Kobold?
                            What are you doing out of the house?
                            Not trying to [b]run away[/b] now, are you?[/color]"
                        [/p]
                        [p]
                            Out of breath, you quickly explain that there's [i]something[/i] bad happening at home.
                            The man asks you what it is, but you have no idea how to explain that his son is beating his wife to death,
                            so you just tell him to [b]come along[/b] and see for himself.
                            He wouldn't believe you if you told the truth, anyway.
                            "[color=red]What is it, my birthday or something?
                            You better not be playing any tricks on me, slave.[/color]"
                            You assure him that you're dead-serious,
                            and the two of you set off back towards the house.
                        [/p]
                        [p]
                            The both of you enter through the still-open back door,
                            the foreboding sounds coming from the kitchen stressing the severity of the situation.
                            As the sight of Falco beating the [b]shit[/b] out of his own mother comes into view,
                            the man of the house freezes in place.
                            His face turns from shock to pure [b]rage[/b].
                            "[color=red]What the [b]hell[/b] is going on here?![/color]"
                        [/p]
                        [p]
                            The bird hadn't even noticed the two of you walking in.
                            He turns around, startled to death by the sound of his father's voice.
                            But he, too, turns to [b]rage[/b].
                            Acting on impulse, the avian grabs a sharp kitchen knife from the counter,
                            and before [b]anyone[/b] can figure out what is happening,
                            Falco [b]stabs[/b] his father in the gut.
                        [/p]
                        [p]
                            The man falls to his knees,
                            coughingly spitting blood into the murderous eagle's face,
                            speckling his white and brown feathers with bright red dots.
                            Juliet is too dazed from the brutal beating she received to figure out what is going on.
                            And you are too absolutely [b]terrified[/b] by the blade-wielding bird to intervene.
                        [/p]
                        [p]
                            As if stabbing him once wasn't enough, Falco retracts the knife, and presses it to the kneeling human's throat.
                            Staring right into his eyes, the avian slices open his father's neck,
                            half-beheading the farmer before pushing him out of the way, down to the ground.
                            Romeo audibly fails to breathe, his lungs rapidly filling with blood.
                            He feebly clutches his haemorrhaged throat, but it is too late.
                            He bleeds out on the floor, slain by his own bastard child.
                        [/p]
                        [p]
                            The old man dealt with,
                            the eagle turns to face you.
                            "[color=yellow][b]You[/b].
                            You lead him here.[/color]"
                            He advances upon you, menacingly wielding the bloodied kitchen knife.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Fight</button>`;

        var tooltip = global.parser.parse(`A fight to the death. You always knew it would come to this.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Beg</button>`;

        var tooltip = global.parser.parse(`Submit to the avian. You are, and always will be his slave.
                                            He just killed a full-grown human twice your size and three times your weight. What chance do you stand? None.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var FarmerMaidTooFarTellChoice = {
    FIGHT: 1,
    SERVE: 2
};
