/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = ctrl.arrival;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new SlaveNoonTwoLookOut(ctrl);
    var secondNext = new SlaveNoonTwoRest(ctrl);

    var firstChoice = SlaveNoonTwoArrivalChoice.LOOKOUT;
    var secondChoice = SlaveNoonTwoArrivalChoice.REST;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            After getting knocked out, you find yourself trapped in ever-more-troubled slumber.
                            Bad dreams come and go,
                            some of the nightmares [i]lifelike[/i] enough to make you toss and tumble around the floor of your wooden cell.
                            The distant sensation of the caravan [i]moving[/i] isn't helping either.
                            Like an insidious poison, it seeps into your mind to corrupt and twist your feverish near-hallucinations further.
                        [/p]
                        [p]
                            The slow, rhythmic clopping of hooves,
                            the slight creaking of wood,
                            the clattering of the accompanying guards' armor,
                            and the lively sounds of the awakening forest,
                            all of these make your brain think back to the act that got you into this situation in the first place.
                            Robbing the transport.
                            That's where it all went wrong.
                        [/p]
                        [p]
                            You dream of how much [b]worse[/b] things could have gone.
                            How the ruffians protecting the transport could have seen you and killed you on the spot.
                            How they might have [b]tortured[/b] you to [b]death[/b].
                            Every scene seems more lifelike than the last.
                            Getting impaled by a spear.
                            Having your loins [b]mutilated[/b] and your tail cut off.
                            Them flaying your scales and feeding your flesh to their dog.
                            Luckily, right as the imaginary caravan master is about to bring a knife to bear on your forcibly held-open eyes,
                            one of the wheels of the cart you are in hits a rock, and the bump is enough to tear you from your hellish imagination.
                        [/p]
                        [p]
                            You let out an exasperated groan.
                            Your head [b]hurts[/b].
                            Your mind slowly rouses from unconsciousness.
                            A bright light is shining into your still-closed eyes, worsening your heavy migraine.
                            The sun?
                            Feels hot enough to be [b]noon[/b].
                            Is it [b]that[/b] late?
                        [/p]`;
        } else {
            toReturn += `[p]
                            Drifting asleep, you find yourself trapped in ever-more-troubled slumber.
                            Bad dreams come and go,
                            some of the nightmares [i]lifelike[/i] enough to make you toss and tumble around the floor of your wooden cell.
                            The distant sensation of the caravan [i]moving[/i] isn't helping either.
                            Like an insidious poison, it seeps into your mind to corrupt and twist your feverish near-hallucinations further.
                        [/p]
                        [p]
                            The slow, rhythmic clopping of hooves,
                            the slight creaking of wood,
                            the clattering of the accompanying guards' armor,
                            and the lively sounds of the awakening forest,
                            all of these make your brain think back to the act that got you into this situation in the first place.
                            Robbing the transport.
                            That's where it all went wrong.
                        [/p]
                        [p]
                            You dream of how much [b]worse[/b] things could have gone.
                            How the ruffians protecting the transport could have seen you and killed you on the spot.
                            How they might have [b]tortured[/b] you to [b]death[/b].
                            Every scene seems more lifelike than the last.
                            Getting impaled by a spear.
                            Having your loins [b]mutilated[/b] and your tail cut off.
                            Them flaying your scales and feeding your flesh to their dog.
                            Luckily, right as the imaginary caravan master is about to bring a knife to bear on your forcibly held-open eyes,
                            one of the wheels of the cart you are in hits a rock, and the bump is enough to tear you from your hellish imagination.
                        [/p]
                        [p]
                            You let out an exasperated groan.
                            You have a slight headache.
                            Your mind slowly rouses from unconsciousness.
                            A bright light is shining into your still-closed eyes, worsening your budding migraine.
                            The sun?
                            Feels hot enough to be [b]noon[/b].
                            Is it [b]that[/b] late?
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Look outside</button>`;

        var tooltip = global.parser.parse(`Rise and shine. Find out where you are.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Rest more</button>`;

        var tooltip = global.parser.parse(`It's too early. You need some more sleep.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var SlaveNoonTwoArrivalChoice = {
    LOOKOUT: 1,
    REST: 2
};
