/**
 * Stage section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoStageChoice.REFUSE;
    var reqController = ctrl.stage;
    var subController = ctrl.preResult;
    var changeController = ctrl.refuse;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.results;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Smile?
                            Hell no.
                            You have [b]no[/b] reason whatsoever to smile.
                            You have been [b]enslaved[/b] and are now being [b]sold[/b] to the highest bidder like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Instead of smiling, you cast an angry glare towards Bartholomew.
                            The human doesn't appreciate your lack of cooperation.
                            His rage just about boiling over, he strides atop the wooden stage,
                            and before you even know what's going on,
                            he roughly [b]grabs[/b] you by your throat,
                            squeezing your windpipe shut while lifting you up high enough to come face-to-face with him.
                        [/p]
                        [p]
                            "[color=brown][b]Normally,[/b][/color]" the human speaks, addressing the crowd without looking at them,
                            glaring into your eyes with an intense look of pure [b]hatred[/b] on his face.
                            "[color=brown]I'd beat the [b]shit[/b] out of this little [b]cretin[/b] for disobeying me.[/color]"
                            You squirm around in Barto's grasp, running slightly low on air, weakly batting at his arm to [b]let go[/b].
                            "[color=brown]But, today, I'll leave that pleasure to [b]you[/b], the people.[/color]"
                            With his free hand, he points towards the crowd to accentuate his speech.
                        [/p]
                        [p]
                            Then, his hand curls into a fist, one which he [b]painfully[/b] rams into your gut with all of his might,
                            knocking what little air remained out of your lungs, while simultaneously letting go of your throat,
                            letting you drop down to the ground.
                            Your legs unable to carry you, you crumple to the floor, curling up into a tiny little ball,
                            clutching your battered stomach.
                            It [b]hurts[/b].
                            The crowd [b]laughs[/b].
                            Your pain is their [b]amusement[/b].
                            You burst out into tears.
                        [/p]
                        [p]
                            [big][color=brown][b]On your feet, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The caravan master rears his foot backwards, threatening to [b]kick[/b] you lest you comply with his demand.
                            Fearing more [b]beatings[/b], you fearfully scramble to your feet,
                            visibly shaken from the human's sudden outburst of anger.
                            "[color=brown]See? If you [b]hurt[/b] it enough, it'll start listening [b]eventually[/b].
                            And if not, you'll have had the pleasure of killing a [b]criminal[/b].[/color]"
                            More crude laughter.
                            More tears.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
