/**
 * The Forest scene. Shown after the Introduction.
 */
function Forest() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "Forest";
    var sceneName = "Forest - Daytime";
    var theme = "forest";
    var controller = new ForestController(sceneId);
    var builder = new ForestBuilder(controller);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
        global.ui.applyTheme(theme);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += builder.buildScene();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        builder.registerListeners();
        controller.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new Forest();
    global.sceneLoader.registerScene(scene.id, scene);
});
