/**
 * Bridge section of the forest scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestBridge(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var nextSceneName = "ForestRiver";
    var nextFolderName = "ForestToVaranar";

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Paying off your debt is the most important thing you need to do right now.
                            It simply [b]can not[/b] wait any longer,
                            lest the Three-Tailed Rat grows more interested in your [b]severed head[/b] than in his protection money.
                            You expect these two hundred coins will buy you some time, at the very least.
                            While not a [i]huge[/i] amount of gold, it's still the most money you've [b]ever[/b] had.
                            And if that still isn't enough to placate your criminal creditors,
                            then you don't think you'll [b]ever[/b] be able to pay off your debt.
                        [/p]
                        [p]
                            If you set off immediately, barring any setbacks, you [i]should[/i] be able to reach the capital by nightfall.
                            You hope you can get to Varanar before the sun goes down.
                            You [b]really[/b] don't want to travel these roads at night.
                            When it's dark, the [b]real[/b] creeps and thugs crawl out of the woodwork.
                            Things are dangerous enough during the day.
                            You're not sure, but you think the local guardsmen only send out patrols when it's light out.
                            That [i]would[/i] explain the daily surge in criminal activities past sunset.
                            Putting your thoughts aside, you begin to walk towards the concealed pathway.
                        [/p]
                        [p]
                            One thing you [i]are[/i] sure of,
                            is that anyone who may be pursuing you will be completely thrown off your track by your sudden change in direction.
                            If those ruffians who were guarding the transport are chasing after you,
                            then your choice to take a [i]less travelled[/i] route will hopefully lead them astray.
                            They may post sentries at the two main bridges,
                            but you doubt they'll be anticipating you to go off the beaten path.
                            Still, best not to take any chances.
                            If you loiter, they may stumble upon you through sheer [b]luck[/b].
                            You pick up your pace, the very notion of getting caught frightening you more than you care to admit.
                        [/p]
                        [p]
                            The path you're on will lead you to a small, old, wooden bridge that the world has seemingly [i]forgotten[/i] about.
                            A crossing that isn't on any map.
                            Not even the locals seem to know of it.
                            At least you haven't [i]seen[/i] anyone cross the bridge.
                            Then again, it's a pretty [i]shoddy[/i] construct.
                            Maybe people don't use it because they fear it'll [b]break[/b], and send them tumbling down into the rocky tides below.
                            You're not as heavy as the humans are, though.
                            You'll be [b]fine[/b].
                            And if it really [i]is[/i] as bad as you remember,
                            then you'll figure something out when you get to the river.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.BRIDGE) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.BRIDGE) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}

