/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsHideStick(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new ForestWoodsHideStickContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var toReturn = `[p]
                            Okay.
                            Calm down.
                            They have a dog.
                            What do dogs like?
                            Dogs like [b]sticks[/b].
                            Luckily for you, you just so happened to pick up a ${global.kobold.inventory.createItemWithTooltip(weapon)} earlier.
                            [i]Maybe[/i], just [b]maybe[/b], you [i]might[/i] be able to distract the beast for long enough for its masters to think it lead them astray.
                        [/p]
                        [p]
                            Your pursuers draw close, close enough for you to identify them.
                            A human, a broadly-built, buff anthromorphic wolf and a feral guard dog doubling as a tracking hound, held on a leash.
                            While the wolf and the human chatter amongst one another, the dog instantly [b]bolts[/b] towards the bush you're hiding in.
                            Luckily, its masters fail to notice its interest.
                        [/p]
                        [p]
                            You grab your ${global.kobold.inventory.createItemWithTooltip(weapon)}, and poke it out of the bush you're in.
                            As you wave it around, the dog stops its aggressive barking, instead seemingly enthralled by the piece of wood.
                            After a bit of teasing, you [b]throw[/b] your stick as far as you can to the side, the dog immediately [b]chasing[/b] after it,
                            nearly pulling the human holding its leash off of his feet.
                            "[color=red]He's got something! Get'em, Rex![/color]"
                        [/p]
                        [p]
                            The dog's handlers follow it to the stick you just threw,
                            completely disillusioned and disappointed with their pet,
                            once they realize it lead them to a [b]piece of wood[/b] instead of to the [b]lizard[/b] they were hoping to catch.
                            With a loud, communal sigh, the human and the wolf decide to call their chase a [i]bust[/i].
                            The dog clutching its new, wooden toy in between its sharp teeth, the party of two and a half head back the way they came.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.preContinue.continued() ? "disabled" : "";
        var isSelected = ctrl.preContinue.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.preContinue.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.bush.get() !== ForestWoodsHideBushChoice.STICK) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.hideStick.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.bush.get() !== ForestWoodsHideBushChoice.STICK) {
            return;
        }

        next.registerListeners();

        if (ctrl.preContinue.continued()) {
            return;
        }

        registerNextListener();
    };
}
