/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsHideStickContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You did it!
                            By manipulating their pet, you managed to outsmart both the human, [b]and[/b] the wolf!
                            Still, for your own safety, you remain concealed inside of the bush for a few minutes more.
                            Y'know, so you can be sure that they [i]aren't[/i] trying to [i]fake you out[/i] or anything.
                        [/p]
                        [p]
                            Once you think the coast is clear, you slowly creep out of the bush, like a shark emerging from a water-surface.
                            After warily taking a look around, you begin to head back home.
                            The sun is slowly starting to set, and you don't want to be out here in the dark, especially not with two hundred coins dangling off your neck.
                        [/p]
                        [p]
                            In retrospect, you are glad things worked out this way.
                            You didn't get caught, nobody got hurt, and the dog seemed pretty happy about its new stick.
                            Sure, the men'll probably get [i]reprimanded[/i] or something for failing to find you, but that's none of your concern.
                            If they were actually [b]paying attention[/b], they would have probably spotted you when you did the whole stick-thing,
                            so they kind of [b]deserve[/b] to get punished, in a way.
                        [/p]
                        [p]
                            That's not to say you [b]want[/b] them to get fired, or whatever.
                            It's just the way things go.
                            Do a bad job, lose your job.
                            But then again, you've never really been employed yourself, and if they [i]had[/i] found you,
                            then things would have probably gone [b]horribly wrong[/b] for you.
                        [/p]
                        [p]
                            As you begin to near your home, you're left with slightly mixed feelings.
                            You [i]think[/i] you did the right thing, but as a thief,
                            the [i]right thing[/i] is not always the [b]best[/b] course of action.
                            Suffice to say, at least [b]you[/b] ended up better off today.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.homeSceneName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.preContinue.continued()) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.preContinue.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
