/**
 * Ignore the scream on the path home.
 * @param {ForestController} controller The forest controller.
 */
function ForestHomeIgnore(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "homeIgnoreContinueButton";

    var content = ` <div class="text">
                        You decide to ignore the screams echoing throughout the forest.
                        This isn't the first time you've heard someone getting mugged, and you doubt it'll be your last.
                        It simply isn't any of your concern.
                        Even if you did decide to intervene, the entire thing could be an elaborate trap or a setup of some kind.
                        Angering a local gang by getting between them and their prey wouldn't be in your best interests, 
                        and neither would getting caught with two hundred gold dangling from your neck.
                    </div>
                    <div class="text">
                        You continue the journey towards your home.
                        The panicked shrieks turn to wailing before slowly fading from hearing, diminished by the increasing distance between the source and your ears.
                        You just got a second chance at life, and you have no reason to risk losing it all in favor of some stranger.
                        That's what you keep telling yourself, as self-inflicted guilt continues to pile up at the back of your head.
                        But what if it was someone caught in a bear trap?
                        Or a poor, innocent child lost in the woods, frightened and alone?
                    </div>
                    <div class="text">
                        You feel kind of sorry for not even checking if you <span class="bold">could</span> have helped.
                        Regardless, it's too late now.
                        You try, but fail, to get the entire ordeal out of your head.
                        Following the concealed pathway, you begin to near the decrepit old shack that you call home.
                    </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        return content;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var disabled = ctrl.home.ignoreHasContinued();
        var choice = `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next part.
     */
    function loadNextPart() {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(ctrl.homeSceneName);
        });
    }
    
    /**
     * Adds a listener to the continue button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.home.ignoreContinue();
            loadNextPart();
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeIgnore";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.home.hasMadePathChoice()) {
            return "";
        }
        if(ctrl.home.getPathChoice() !== ForestHomePathChoiceEnum.CONTINUE) {
            return "";
        }
        
        var change = ctrl.home.ignoreStatusChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if(ctrl.home.getPathChoice() !== ForestHomePathChoiceEnum.CONTINUE) {
            return;
        }
        if(ctrl.home.ignoreHasContinued()) {
            return;
        }
        
        registerContinueListener();
    };
}
