/**
 * Controller for the unknown part of the forest scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestUnknownYankController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;

    var baseId = "unknownYankBase";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    this.base = new BaseController(baseId);
    this.grab = new GrabController("unknownYankGrab");
    this.hit = new HitController("unknownYankHit");
    this.dodge = new DodgeController("unknownYankDodge");
    this.envelop = new EnvelopController("unknownEnvelop");

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    function BaseController(key) {
        var changeId = key + "Change";
        this.get = function () {
            return global.kobold.history.getKey(id, key);
        };
        this.set = function (choice) {
            global.kobold.history.setKey(id, key, choice);
        };
        this.has = function () {
            return global.kobold.history.has(id, key);
        };
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeId, true, function () {
                global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
                global.kobold.status.mental.decrease(20, "Ruined wool sweater");
            });
            return global.ui.change.buildNotification([
                new Change("Ruined favorite shirt", "Intelligence", -1),
                new Change("Ruined favorite shirt", "Sanity", -20)
            ]);
        };
    }

    function GrabController(key) {
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
    }

    function HitController(key) {
        var changeId = key + "Change";
        var envelopId = key + "Envelop";
        var successId = key + "Success";
        var successChangeId = key + "SuccessChange";
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
        this.success = function () {
            global.kobold.history.setKey(id, successId, true);
        };
        this.toSuccess = function () {
            return global.kobold.history.has(id, successId);
        };
        this.envelop = function () {
            global.kobold.history.setKey(id, envelopId, true);
        };
        this.toEnvelop = function () {
            return global.kobold.history.has(id, envelopId);
        };
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeId, true, function () {
                global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
                global.kobold.status.physical.decrease(25, "Hit your head");
            });
            return global.ui.change.buildNotification([
                new Change("Hit your head", "Intelligence", -1),
                new Change("Hurt your hand", "Health", -10),
                new Change("Hit your head", "Health", -15),
            ]);
        };
        this.successChange = function () {
            global.kobold.history.doIfNotSet(id, successChangeId, true, function () {
                global.kobold.stats.increaseStat(StatsEnum.STRENGTH, 1);
                global.kobold.status.physical.decrease(20, "Various minor wounds");
                global.kobold.status.mental.increase(10, "Tentacle monster beatdown");
                global.kobold.status.stamina.decrease(25, "Tentacle monster fight");
                global.kobold.inventory.equipment.wear(new RippedWoolSweater());
            });
            return global.ui.change.buildNotification([
                new Change("Combat trophy", global.kobold.inventory.createItemWithTooltip(new RippedWoolSweater()), +1),
                new Change("Display of power", "Strength", +1),
                new Change("Victory", "Sanity", +10),
                new Change("Lots of minor wounds", "Health", -20),
                new Change("Long fight", "Stamina", -25)
            ]);
        };
    }

    function DodgeController(key) {
        var changeId = key + "Change";
        var continueChangeId = key + "ContinueChange";
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeId, true, function () {
                global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
                global.kobold.status.stamina.decrease(10, "Dodging tentacles");
            });
            return global.ui.change.buildNotification([
                new Change("Skillful dodging", "Agility", +1),
                new Change("Skillful dodging", "Stamina", -10)
            ]);
        };
        this.continueChange = function () {
            global.kobold.history.doIfNotSet(id, continueChangeId, true, function () {
                global.kobold.status.mental.decrease(5, "Lamenting sweater");
                global.kobold.status.stamina.decrease(30, "Running from monster");
                global.kobold.inventory.equipment.wear(new RippedWoolSweater());
            });
            return global.ui.change.buildNotification([
                new Change("Recovered sweater", global.kobold.inventory.createItemWithTooltip(new RippedWoolSweater()), +1),
                new Change("Lamenting sweater", "Sanity", -5),
                new Change("Running on fumes", "Stamina", -30)
            ]);
        };
    }
    
    function EnvelopController(key) {
        var changeId = key + "Change";
        var continueChangeId = key + "ContinueChange";
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeId, true, function () {
                if(global.kobold.body.dick) {
                    global.kobold.body.cockslitVirgin = false;
                } else {
                    global.kobold.body.vaginalVirgin = false;
                }
                if(global.kobold.inventory.equipment.pants) {
                    global.kobold.inventory.equipment.pants.stain("Honey");
                }
                if(global.kobold.inventory.equipment.underwear) {
                    global.kobold.inventory.equipment.underwear.stain("Honey");
                }
                global.kobold.status.exertion.increase(20, "Tentacle-fucked");
            });
            return global.ui.change.buildNotification([
                new Change("Tentacle-fucked", "Sexual exhaustion", +20, true)
            ]);
        };
        this.continueChange = function () {
            global.kobold.history.doIfNotSet(id, continueChangeId, true, function () {
                global.kobold.status.mental.decrease(20, "Abused by tentacle monster");
                global.kobold.inventory.equipment.wear(new RippedWoolSweater());
            });
            return global.ui.change.buildNotification([
                new Change("Abused", "Sanity", -20),
                new Change("Recovered sweater", global.kobold.inventory.createItemWithTooltip(new RippedWoolSweater()), +1)
            ]);
        };
    }
}

