/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSwimming(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.swimming;
    var changeController = ctrl.swimming;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverKeep(ctrl);
    var secondNext = new ForestRiverFreeze(ctrl);

    var firstChoice = ForestRiverSwimmingChoice.KEEP;
    var secondChoice = ForestRiverSwimmingChoice.FREEZE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var stripped = ctrl.swim.get() === ForestRiverSwimChoice.STRIP;
        var toReturn = `[p]
                            You stride forwards, and enter the water properly.
                            In one step, your feet are immersed in the freezing liquid.
                            You shiver and grit your teeth, but you keep going.
                            Your shins go under, and then your loins become submerged,
                            the ice-cold liquid creeping into every crevice and orifice, chilling you to the very bone.
                            You take a moment to adapt to the temperature.
                            Then, you decide to take the plunge.
                        [/p]
                        [p]
                            Exhaling deeply, you squat down, [b]plunging[/b] your upper body into the ice-cold water.
                            Your entire frame trembles, your teeth chattering together, the temperature [b]far[/b] too low for a little lizard like you.
                            It's [b]so[/b] cold, it almost [b]burns[/b].
                            In a way, the frigid temperatures are sort of [i]rejuvenating[/i], the adrenaline flooding through your body making you feel truly [b]alive[/b].
                            But in another way, it's just [b]cold enough to kill[/b].
                            You can feel the tip of your tail starting to [b]freeze[/b].
                            You have to stay active, to keep the blood pumping throughout your body.
                            You need to keep moving.
                        [/p]
                        [p]
                            You lean forwards, and begin to [b]swim[/b] across the river, propelling yourself through the water with slow,
                            deliberate motions of your shaking limbs.
                            You're already breathing heavily, not from physical exertion, but from the sheer [b]frigidness[/b] of the liquid surrounding you.
                            It feels like your chest is being [b]constricted[/b] by the near-zero temperatures.
                            Your troubled breathing luckily lessens,
                            your respiratory system relaxing the more accustomed you grow to your new surroundings,
                            and the more active your body becomes.
                            Kobolds are nothing if not adept at adapting.
                        [/p]
                        [p]
                            The current isn't too bad, near the bank of the river.
                            But the further out you get into the water, the stronger it becomes.
                            Almost a quarter of your way across, as you get into the [b]deep[/b] part of the river, the water's pull tangibly intensifies.
                            While it's nothing you can't fight,
                            the current still makes what was [i]supposed[/i] to be a relaxing swim into more of a [b]struggle[/b] to make it across.
                        [/p]
                        [p]
                            About halfway through your arduous journey, a large rock a little upstream, underneath the bridge, lessens the flowing water's constant pull.
                            You consider taking a slight [i]breather[/i] from swimming,
                            but the sun dropping lower and lower serves as a constant, stern reminder of your strict schedule
                            -- which has already been disrupted by having to swim instead of walking across the bridge.
                            You're a lot quicker on land than you are in the water.
                            Come to think of it, you're pretty much a [b]sitting duck[/b] for anyone with a keen eye and a ranged weapon.
                            Right as that thought crosses your mind, you hear noise behind you, over the soft sounds of the rippling flow of the river.
                            Branches snapping, foliage being pushed aside, [b]footsteps[/b].
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hold it right there, kobold![/color]"
                            [/big]
                        [/p]
                        [p]
                            [b]Oh no[/b].
                            Your heart sinks.
                            A knot forms in your stomach.
                            For a moment, you fear it may be the transport guards chasing after you.
                            A quick glance backwards disconfirms your worst fears.
                            Humans.
                            Three of them.
                            They don't look like the group you saw escorting the caravan.
                            They're less well dressed, clad in patched together, obnoxiously-yellow dyed attire.
                            Bandits?
                            Albeit not very subtle ones.
                        [/p]
                        [p]
                            One of the men is armed with a slingshot, loaded with a sharp, pointy rock, aimed directly at [b]you[/b].
                            Another ${stripped ? `grabs your discarded clothing,
                            giving it a crude [b]sniff[/b] before [b]tearing[/b] the flimsy fabric apart. Then, he` : ``} brandishes a regular sling,
                            which he swings in a rotary fashion, preparing to let loose a more [i]blunt[/i] piece of stone.
                            The third, the most muscular of the group, wields a large, wooden club, bigger than your head.
                        [/p]
                        [p]
                            Definitely not a [i]refined[/i] group of thugs.
                            Textbook definition of a gang of [b]ruffians[/b].
                            Crude weapons, crude attire, crude [b]attitude[/b].
                            Noticing that he's caught your attention, the brawny member of the group calls out to you once more.
                            "[color=green]This is [b]our[/b] part of the river.
                            If you want to cross here, you're going to have to pay us a [b]fine[/b].[/color]"
                            The human takes off his shirt, exposing his ripped and muscular upper body.
                            He looks like he could absolutely [b]tear[/b] you in [b]half[/b].
                        [/p]
                        [p]
                            A fine?
                            You [i]guess[/i] you could spare like maybe five or ten coins?
                            The bandit leader isn't done talking, however.
                            "[color=green]And since your kind isn't known for being [b]rich[/b], I'll settle for your [b]body[/b] instead.[/color]"
                            Wait, what?
                            The human tosses his weapon to the side, and lowers his pants, his large, cut, half-erect member coming into view.
                            He's [b]hung[/b] like a horse!
                        [/p]
                        [p]
                            "[color=cyan]Move, and you [b]die[/b].[/color]" threatens the slingshot-wielding thug.
                            The sling-armed human nods in agreement.
                            Their leader, meanwhile, [b]strides[/b] into the water, completely unfazed by the temperature.
                            Do you attempt to swim away, or do you remain in place?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Keep going</button>`;

        var tooltip = global.parser.parse(`Get the hell out of here!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 170px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Freeze</button>`;

        var tooltip = global.parser.parse(`Remain in place. Maybe the man'll take some coins instead.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverSwimmingChoice = {
    KEEP: 1,
    FREEZE: 2
};
