/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverWeapon(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverFreezeChoice.WEAPON;
    var reqController = ctrl.freeze;
    var subController = ctrl.weapon;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverReconsider(ctrl);
    var secondNext = new ForestRiverStrike(ctrl);

    var firstChoice = ForestRiverWeaponChoice.RECONSIDER;
    var secondChoice = ForestRiverWeaponChoice.STRIKE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var weaponTT = global.kobold.inventory.createItemTooltip(weapon);
        var rockTT = global.kobold.inventory.createItemTooltip(new Rock());
        var toReturn = `[p]
                            Raise your hands?
                            Fuck no.
                            You're not surrendering to some [b]oaf[/b] just because he has a pair of friends and more muscle-mass than your entire body weight.
                            He may be strong, but you doubt he can take a hit to the top of his head.
                            In fact, out here in the water, you'd say the playing field is pretty [i]even[/i].
                            Out on dry land, you'd have to jump up high to be able to even [b]reach[/b] his head.
                            But in the water, he isn't that much taller than you.
                        [/p]
                        [p]
                            Powerful as he may be, you intend to knock the man out [b]before[/b] he manages to bring his impressive muscles to bear.
                            ${weapon ? `Underneath the surface of the water, you brandish your ${weaponTT}.
                            ` : `For a moment, you pretend to drown, letting yourself sink to the bottom of the river,
                            so you can pick up a ${rockTT} to use as a temporary weapon.
                            "[color=green]I almost thought you were trying to make a run for it.[/color]"
                            the burly man comments, as you surface once more.`}
                            As ${weapon ? `the human` : `he`} approaches, however, doubt begins to cloud your mind.
                            He's [b]really[/b] big.
                            What if this [i]doesn't[/i] work?
                            How will his friends react?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Reconsider</button>`;

        var tooltip = global.parser.parse(`This guy's a bit too [i]buff[/i] to pick a fight with.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Strike</button>`;

        var tooltip = global.parser.parse(`Surprise is your greatest weapon. One swift blow is all you need.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverWeaponChoice = {
    RECONSIDER: 1,
    STRIKE: 2
};
