/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeep(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimmingChoice.KEEP;
    var reqController = ctrl.swimming;
    var subController = ctrl.keepGoing;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new ForestRiverKeepOther(ctrl);
    var secondNext =  new ForestRiverKeepUpstream(ctrl);
    var thirdNext =  new ForestRiverKeepDownstream(ctrl);

    var firstChoice = ForestRiverKeepChoice.OTHER;
    var secondChoice = ForestRiverKeepChoice.UP;
    var thirdChoice = ForestRiverKeepChoice.DOWN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You're [b]not[/b] letting yourself fall into the hands of this [b]brute[/b]!
                            Knowing these lowlifes, he might take your money [b]and[/b] your virginity.
                            You can't let that happen.
                            Those rock-based weapons, while undoubtebly lethal, don't look very [i]accurate[/i].
                            You don't think they'll be able to hit you, but then again, you don't know how [i]skilled[/i] the men are.
                            The buff bandit doesn't look like much of a swimmer.
                            You doubt he'll give chase if you manage to put some distance between the two of you.
                        [/p]
                        [p]
                            All you need to do is get [b]out[/b] of the water, so you can flee into the forest, or towards the hamlet.
                            If you go upstream, you can try to hide behind the rock that protects you from the current, and then figure out what you'll do from there.
                            Downstream, the water's pull might be able to give you the extra [i]speed[/i] that you need to escape the men.
                            As a small, lightweight kobold, the current'll accelerate you far more than it will the hulking brute chasing you.
                            With some luck, it'll make you fast enough to avoid the rocks that'll be hurled at you.
                        [/p]
                        [p]
                            Alternatively, you could keep heading straight ahead, towards the other side of the river.
                            If you can reach dry land without getting hit or grabbed, then you should be able to get to the hamlet before they catch up to you.
                            It's a pretty [i]predictable[i] path, but at the same time, you'll be putting some extra distance between the rock-hurlers and yourself.
                            And that may be all that's needed for them to [b]miss[/b].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Other side</button>`;

        var tooltip = global.parser.parse(`Keep going straight ahead!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 185px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Upstream</button>`;

        var tooltip = global.parser.parse(`Fight the current and head for the bridge.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Downstream</button>`;

        var tooltip = global.parser.parse(`Go with the flow to pick up extra speed.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var ForestRiverKeepChoice = {
    OTHER: 1,
    UP: 2,
    DOWN: 3
};

