/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTeaDisagree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnTeaDisagreeButton";

    var next = new NotBarnTeaDisagreeContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var int = ctrl.misc.intelligence();
        var cha = ctrl.misc.charisma();
        var toReturn = `[p]
                            No!
                            What Cassidy is doing is [b]wrong[/b], no matter how you look at it.
                            Take yourself, for example.
                            If she had her way, would you be in one of those pens right now?!
                            As you struggle to formulate a well-worded answer, the vixen finally manages to open the door to her house.
                            Without replying, you silently follow her inside, if just to give her a piece of your mind.
                        [/p]
                        [p]
                            Cassidy's house is as fancy on the inside as it is on the outside.
                            The entire place is well-lit by candles.
                            Various paintings of kobolds and canines alike line the walls.
                            You stay your tongue as she leads you to the den, where you get to take a seat in a luxurious padded chair.
                            The lack of words between the two of you continues as the vixen speechlessly wanders into the kitchen.
                            She knows you don't agree with her ways.
                            She'd have to be blind [i]not[/i] to be able to read your expression.
                            It is only when she returns with a pair of filled teacups, that you voice your concerns.
                        [/p]
                        [p]
                            The vulpine hands you your tea, and then sits down ever so daintily.
                            She sips her own drink, pinky finger fully extended.
                            She'd almost be lady-like if she weren't half-naked wearing cowboy attire.
                            [i]Almost[/i].
                        [/p]`;

        if (int < 6 && cha < 6) {
            toReturn += `[p]
                            After a long sip on her end, the two of you enter the most [i]philosophical[/i] debate you've [b]ever[/b] been a part of.
                            Well, at least it [i]seems[/i] a bit more intricate than your usual dialogue.
                            But, as a kobold, even that isn't saying much.
                            You have to say, she makes a pretty darn decent case for herself,
                            whereas your only arguments are that what she's doing is [i]unethical[/i], and [i]wrong[/i].
                            But, as she argues, you may just [i]view[/i] it that way because you [b]are[/b] a kobold.
                        [/p]
                        [p]
                            As the both of you finish your drinks, the discussion winds down.
                            The canine rises from her seat, and escorts you to the door.
                            You try to [i]act[/i] as though you still condemn Cassidy's trade,
                            but deep down inside, you know you don't.
                            Not anymore.
                            Or at least [i]not as much[/i].
                            And it [b]shows[/b].
                            Besides, she very clearly [i]won[/i] the argument.
                            You can hate what she does all you'd like,
                            but that won't change the fact that she's undeniably in the right here.
                        [/p]`;
        } else if (int >= 6 && cha < 6) {
            toReturn += `[p]
                            After a long sip on her end, the two of you enter the most [i]philosophical[/i] debate you've [b]ever[/b] been a part of.
                            Well, at least it [i]seems[/i] a bit more intricate than your usual dialogue.
                            But, as a kobold, even that isn't saying much.
                            The vixen makes a pretty compelling case for herself.
                            She brings up many points that you'd never even considered up until now.
                            It seems that she's thought about the ethics of her trade far more than you'd have guessed.
                        [/p]
                        [p]
                            Still, you don't [b]fully[/b] agree with what she's saying.
                            Kobolds may be a [i]detrimental[/i] part of society,
                            but that doesn't make your entire kind any lesser than the outlaws of other species,
                            who [b]still[/b] have basic rights, despite [b]also[/b] not contributing to society as a whole.
                            Sadly, you fail to convey this sentiment properly.
                            In between stuttering, forgetting your train of thoughts halfway through and the vixen constantly [b]twisting[/b] your words,
                            you end up concluding the very opposite of what you had in mind.
                        [/p]
                        [p]
                            As the both of you finish your drinks, the discussion winds down.
                            The canine rises from her seat, and escorts you to the door.
                            You try to [i]act[/i] as though you still condemn Cassidy's trade,
                            but deep down inside, you know you don't.
                            Not anymore.
                            Or at least [i]not as much[/i].
                            And it [b]shows[/b].
                            Besides, she very clearly [i]won[/i] the argument.
                            You can hate what she does all you'd like,
                            but that won't change the fact that she's undeniably in the right here.
                        [/p]`;
        } else if(cha >= 6 && int < 6) {
            toReturn += `[p]
                            After a long sip on her end, the two of you enter the most [i]philosophical[/i] debate you've ever been a part of.
                            Well, at least it [i]seems[/i] a bit more intricate than your usual dialogue.
                            But, as a kobold, even that isn't saying much.
                            You have to say, she makes a pretty darn decent case for herself.
                            Still, you [b]refuse[/b] to let her gain any ground.
                        [/p]
                        [p]
                            You argue that you are the same as her.
                            You can think, you can dream and you can drink tea just as well as the vixen can.
                            Viewing [b]any[/b] sentient being as inherent [b]less[/b] than others is plain [b]wrong[/b].
                            You [b]deserve[/b] the same rights as anyone else!
                        [/p]
                        [p]
                            Cassidy rebutes that, just because two species are capable of reasonable thought and speech, that does [b]not[/b] make them the same.
                            She asks you to consider the dragons, founders and rulers of multiple, successive, continent-spanning empires.
                            "[color=orange]Has any kobold ever done [b]anything[/b] of even remotely equal merit?[/color]"
                        [/p]
                        [p]
                            Of course not.
                            The biggest organized group of kobolds you know is the gang you owe money to.
                            Instead of palaces, your kind prefers to spend their lives in caves, huts and temporary encampments, if they have a place to call home at all.
                            Kobolds would rather skulk through the night like thieves and vagabonds as opposed to holding civil discussions during the day.
                        [/p]
                        [p]
                            The vulpine has made her point, yet still she does not relent.
                            "[color=orange]How many of your kind even know how to read, let alone write?
                            Kobolds are not merely [i]smaller[/i] than other species, they are strictly [b]inferior[/b] in every way imaginable.
                            [b]That[/b] is why [i]they[/i] -- that is why [b]you[/b] -- have no rights.[/color]"
                        [/p]
                        [p]
                            As the both of you finish your drinks, the discussion winds down.
                            The canine rises from her seat, and escorts you to the door.
                            You try to [i]act[/i] as though you still condemn Cassidy's trade,
                            but deep down inside, you know you don't.
                            Not anymore.
                            Or at least [i]not as much[/i].
                            And it [b]shows[/b].
                            Besides, she very clearly [i]won[/i] the argument.
                            You can hate what she does all you'd like,
                            but that won't change the fact that she's undeniably in the right here.
                            Kobolds are inferior to other sentient beings, and you just need to learn to live with that fact.
                        [/p]`;
        } else {
            toReturn += `[p]
                            After a long sip on her end, the two of you enter the most [i]philosophical[/i] debate you've [b]ever[/b] been a part of.
                            Well, at least it [i]seems[/i] a bit more intricate than your usual dialogue.
                            But, as a kobold, even that isn't saying much.
                            The vixen makes a pretty compelling case for herself, a fact which you readily and openly admit.
                            Still, you refuse to give her even an [b]inch[/b].
                            Kobolds may not be as valuable to society as other species, but that doesn't mean they should be treated any worse!
                        [/p]
                        [p]
                            The argument between the two of you goes back and forth.
                            The vixen comes up with a good point why your kind should [b]not[/b] have any rights,
                            you rebuttle with a cleverly constructed comment relating kobolds to criminals of other species,
                            the woman replies that criminals may reform, yet kobolds will always be kobolds,
                            and so the discussion continues for the better part of an hour.
                        [/p]
                        [p]
                            As the both of you finish your drinks, the discussion winds down.
                            The canine rises from her seat, and escorts you to the door.
                            Ultimately, neither of you managed to convince the other.
                            She had a few points for which you had no rebuttal, and you in turn left her speechless more than once.
                            In the end, the two of you agree to disagree.
                            Cassidy gave you a lot to think about, and you gave her a few good reasons to stop doing what she's doing.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildContinueChoice() {
        var disabled = ctrl.postnotbarn.has() ? "disabled" : "";
        var isSelected = ctrl.postnotbarn.has();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildContinueChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postnotbarn.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTeaDisagree";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.DISAGREE) {
            return "";
        }
        global.ui.applyTheme("hamlet_mansion");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.teaDisagreeChange();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.DISAGREE) {
            return;
        }

        next.registerListeners();

        if (ctrl.postnotbarn.has()) {
            return;
        }

        registerContinueListener();
    };
}
