/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellKeepClimbingFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.climbUpFail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You need to keep going.
                            This might be your only way out, and you can't give up just because of a single bad thing happening.
                            Besides, you're already halfway to the top.
                            It'd be a darn [b]shame[/b] to quit now!
                            The way down would be as much of a climb as the way up is.
                            Plus, you're far more motivated by the thought of being [b]freed[/b] from this [i]watery prison[/i]
                            than you are by the premise of being stuck at the bottom [i]again[/i].
                        [/p]
                        [p]
                            It's decided, then.
                            You have to reach the top, no matter how tired or worn out your muscles may be.
                            You raise your arm to a different rock on the same level as the one that broke off a minute ago.
                            Then, the unexpected happens.
                            Like the one before it, this stone, too, breaks from the wall!
                            You are thrown off balance a second time, feeling even more startled than before.
                            You would never have expected two [b]adjacent[/b] rocks to [b]both[/b] be loose!
                        [/p]
                        [p]
                            You try to reach for a new gripping point, much like you did before,
                            but this time you [b]aren't[/b] so lucky as to be able to simply grab a new rock.
                            You manage to stay put, balancing only on your feet, for just a few seconds more.
                            Time itself seems to slow down, as you tumble backwards, falling from the wall.
                        [/p]
                        ${global.ui.condFail(ctrl.misc.strength() < 6 ? `Strength below 6` : `Agility below 6`)}
                        [p]
                            Instinctively, to try to prevent yourself from [b]scraping[/b] against the well's rocky interior,
                            you kick yourself off from the ledge you were standing on at the very last moment.
                            Bad idea.
                            Due to the space you're in being so [b]confined[/b],
                            you end up harshly [b]bashing[/b] the soft back of your head against the other side of the well.
                            Your vision goes black.
                            You pass out, your limp body plummeting down into the cold water below.
                        [/p]
                        [hl]
                        [p]
                            You wearily open your eyes, what you can only imagine to be minutes, or maybe [b]hours[/b] after passing out and falling down.
                            You find yourself floating on your back on the surface of the frigid well water.
                            Your head hurts.
                            Your [b]everything[/b] hurts.
                            You slowly come to an upright swimming position, clutching the back of your skull.
                            Is that...[i]blood[/i] you feel?
                        [/p]
                        [p]
                            You don't get long to inspect your injuries, or even to contemplate what happened.
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake, clearing your foggy mind despite rousing a killer headache.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
