/**
 * Builder for the Introduction scene.
 * @param {IntroductionController} controller The controller managing this scene.
 */
function IntroductionBuilder(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var thirdPart = new IntroductionThirdPart(controller);
    var secondPart = new IntroductionSecondPart(controller, thirdPart);
    var firstPart = new IntroductionFirstPart(controller, secondPart);
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Progressively builds the contents of the scene.
     * @returns {string} The innards of the scene, as a HTML string.
     */
    this.buildScene = function() {
        var scene = firstPart.build();
        scene += secondPart.build();
        scene += thirdPart.build();
        return scene;
    };
    
    /**
     * Registers all the required button listeners.
     */
    this.registerListeners = function() {
        firstPart.registerListeners();
        secondPart.registerListeners();
        thirdPart.registerListeners();
    };
}
