/**
 * The third part of the introduction.
 * @param {IntroductionController} controller The controller.
 */
function IntroductionThirdPart(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var nextScene = "Forest";

    var continueButtonId = "continueButton";
    var contentStart = `<div class="text">`;
    var contentMiddle = `   You are a thief. You make a living by sneaking into the
                            various camps of passersby, bandits and other forest-inhabitants,
                            stealing whatever you can and then hightailing it out of there hoping you weren't seen.
                            This tactic has worked out pretty well for you in the past.
                            For several years, you've managed to stay afloat, if just barely.
                            Some months you even had the money to buy yourself some actual food, 
                            instead of living off the scraps of others.
                        </div>
                        <div class="text">
                            Those golden days are over.
                            The Three-Tailed Rat Clan has recently raised its <span class="italic">fee</span>
                            to a level you can no longer afford. 
                            Fifty coins per month was a reasonable tariff, but one hundred is simply
                            <span class="bold">too</span> much for a simple kobold like yourself to steal on a monthly basis.
                            You have no choice <span class="bold">but</span> to pay, however. 
                            You have nowhere else to go, you've grown rather attached to your little shack in the woods,
                            and you'd rather <span class="bold">not</span> risk the ire of one of the deadliest gangs around.
                        </div>
                        <div class="text">
                            Over the past few months, you've been working your <span class="bold">ass</span> off trying to make ends meet.
                            You've been taking risks: stealing from caravans, stalking bandits to pick their prey clean of any leftover coin,
                            even making a trip to the city to try your hand at pickpocketing. 
                            Despite your best attempts, you've accumulated a significant amount of debt.
                            <span class="bold">Two hundred and fifty</span> coins worth, to be precise.
                        </div>
                        <div class="text">
                            The Three-Tailed Rat himself has issued you a warning.
                            Of course, not in person. 
                            Nobody talks to the Rat but his second-in-command.
                            A courier delivered a letter to your very doorstep.
                            Three days. 
                            That's all the time you had to repay your debt.
                            <span class="bold">Or else.</span>
                        </div>`;

    var contentMiddle2 = `  <div class="text">
                            Needless to say, the worries clouding your mind haven't been very conducive to your trade.
                            In fact, you've fumbled every single heist you've attempted since receiving the note.
                            Worse yet, last night, you were unfortunate enough to drop your meagre coin pouch while running from a pair of mounted caravan guards.
                            Today, the last day you had to pay up, you spent scouring every inch of the forest floor in a desperate attempt to recover your purse.
                        </div>
                        <div class="text">
                            The few coins within might have been enough to at least buy you some time, but alas.
                            The horsemen must have taken it as their just due. 
                            Or maybe another group stumbled upon it. 
                            Heck, the neck cord could have wrapped itself around some wild animal's leg for all you know.
                        </div>
                        <div class="text">
                            In the early afternoon, you were about ready to give up.
                            Not just on finding your lost pouch, but on <span class="bold">everything</span>.
                            You were done for.
                            A quarter of a thousand gold due tonight, and you hadn't a coin to your name.
                            All seemed lost.
                        </div>
                        <div class="text">
                            Still, a flicker of hope remained.
                            At least you didn't get caught by the horsemen. `;

    var contentEnd = `   Maybe, just maybe, you could meet your deadline still.
                            You just needed to score <span class="bold">one big hit.</span>
                            Driven by the will to live, you set out to do what you do best.
                        </div>`;


    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the first section of the third part.
     * @returns {string} The first section of the third part.
     */
    function buildName() {
        var gender = ctrl.getGenderChoice();
        var name = ctrl.getNameChoice();
        var part = contentStart;
        part += `Your name is <span class="bold">${name}</span>. `;
        part += contentMiddle;
        part += contentMiddle2;
        if (gender == GenderEnum.MALE) {
            part += `And the way you escaped them by <span class="bold">climbing up a tree</span> was pretty darn impressive.`;
        } else {
            part += `And the way you escaped them by <span class="bold">hiding in a bush</span> was pretty darn impressive.`;
        }

        part += contentEnd;
        return part;
    }

    /**
     * Builds and returns the continue button at the end of the scene.
     * @returns {string} The continue button.
     */
    function buildContinueButton() {
        var disabled = ctrl.hasContinued();
        var button = `<button class="button bigbutton continuebutton" id="${continueButtonId}" ${disabled ? "disabled" : ""}>`;
        button += `Continue &gt;&gt`;
        button += `</button>`;
        return button;
    }

    /**
     * Registers a listener for the continue button.
     */
    function registerContinueButtonListener() {
        $("#" + continueButtonId).click(function () {
            ctrl.pressContinue();
            global.ui.fadeOutContent(function () {
                global.sceneEnd();
                global.sceneLoader.loadScene(nextScene);
            });
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "part3";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {bool} invisible True if the entire section should be invisible.
     */
    this.build = function (invisible) {
        if (!ctrl.hasMadeNameChoice()) {
            return "";
        }
        
        var change = ctrl.thirdPartMentalEffects();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildName(change);
        part += change;
        part += buildContinueButton();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.hasContinued()) {
            return;
        }
        registerContinueButtonListener();
    };
}
