/**
 * Controller for the Varanar, Afternoon Three scene.
 * @param {string} sceneId The id of the scene.
 * @param {AfternoonThree} ui The scene itself, so it can be reloaded.
 */
function AfternoonThreeController(sceneId, ui) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "SlaveAfternoonTwo";
    this.nextFolderName = "Enslavement/DayTwo";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");
    this.entrance = new ChoiceController(id, "originEntrance");

    this.proposal = new ChangeController(id, "proposal", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.fragments = {};

    this.subControllers = {};
    this.subControllers.parlor = new AfternoonThreeParlorController(id, this);
    this.subControllers.ruby = new AfternoonThreeRubyController(id, this);

    //this.bgm = new AudioController(id, "res/audio/varanar/noonthreestore.mp3", 100);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    var statusKey = "statusReset";
    var statsKey = "statsReset";
    var bodyKey = "bodyReset";
    var inventoryKey = "inventoryReset";

    /**
     * Sets the restore point.
     * Should be called during scene-arrival.
     */
    this.set = function () {
        global.kobold.history.setIfNotSet(id, statusKey, JSON.parse(JSON.stringify(global.kobold.status)));
        global.kobold.history.setIfNotSet(id, statsKey, JSON.parse(JSON.stringify(global.kobold.stats)));
        global.kobold.history.setIfNotSet(id, bodyKey, JSON.parse(JSON.stringify(global.kobold.body)));
        global.kobold.history.setIfNotSet(id, inventoryKey, JSON.parse(JSON.stringify(global.kobold.inventory)));
    };

    /**
     * Resets the entire scene to the starting point.
     * Starting point MUST first have been set with set().
     * Reverts inventory, body, shared history, stats and statuses.
     * Note that the main panel will still need to be cleared and reloaded after this.
     */
    this.reset = function () {
        global.kobold.history.shared.varanar.dayThree.afternoon.load();
        global.kobold.status.load(global.kobold.history.getKey(id, statusKey));
        global.kobold.stats.load(global.kobold.history.getKey(id, statsKey));
        global.kobold.body.load(global.kobold.history.getKey(id, bodyKey));
        global.kobold.inventory.load(global.kobold.history.getKey(id, inventoryKey));
        global.kobold.history.set(id, {});
        that.fakeAutosave();
    };

    /**
     * Reloads the scene.
     * Use after resetting.
     */
    this.reload = function () {
        $("#content").fadeOut(400, function () {
            ui.load();
            $("#content").fadeOut(0);
            $("#content").fadeIn(400);
        });
    };
}
