/**
 * Arrival section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new AfternoonThreeParlorEntrance(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You'd rather not risk getting on the Three-Tailed Rat Clan's radar.
                            Even [i]if[/i] being amongst fellow kobolds could lift your spirits a little, it's not worth the risk.
                            Instead of continuing on, you walk down a side street, hoping to find [i]anything[/i] of interest.
                        [/p]
                        [p]
                            Delving deeper into this less savory neighbourhood,
                            you see and [i]smell[/i] that this place is every bit as much of a [i]slum[/i] as the kobold district is.
                            The roads are littered with small bits of refuse and trash, contributing to an unsavory odor that permeates the area.
                            At least there's plenty of [i]light[/i] here, the bright afternoon sun lighting your path, even through the clouds in the sky.
                        [/p]
                        [p]
                            While the odor is disconcerting, your inner thief is greatly pleased by the large amounts of alcoves and tiny alleyways.
                            Perfect places to conceal yourself in, should you need to hide.
                            The streets are pretty empty.
                            There's a few humans and anthros going about their business,
                            but overall, this place is a [b]lot[/b] less packed than the grand avenue.
                            Everyone's probably either indoors or busy working somewhere.
                        [/p]
                        [p]
                            The few businesses in this [i]dismal[/i] backstreet are exactly what you expected to find in such a rundown area.
                            Shady pawn shops, rundown taverns, even a couple of ramshackle inns which you believe to be houses of ill-repute in disguise.
                            You doubt even half these places would serve a kobold like yourself, and you don't feel like stealing things from poor people.
                        [/p]
                        [p]
                            You mindlessly wander on, exploring the slums a little.
                            Besides the stench, this doesn't seem like such a bad place to live.
                            You bet the actual inhabitants would care to argue, though.
                            After a few minutes of strolling,
                            a large wooden sign attached to a rundown brown brick building catches your attention.
                        [/p]
                        [p]
                            [color=brown][big][b]THE KOBOLD'S DEN[/b][/big][/color]
                        [/p]
                        [p]
                            Below this text, the sign features two crudely painted figures, one of which is distinctly lizard-shaped.
                            A kobold, most likely.
                            The other looks to be an anthro of some kind.
                            Maybe a bear?
                            Or a chubby wolf?
                            You can't quite figure out what it's supposed to be, the drawing too poorly made to discern the actual species.
                            Regardless, the anthro is resting on its stomach, atop what appears to be a bed or a table.
                            The kobold appears to be rubbing the furred creature's back.
                        [/p]
                        [p]
                            This must be a massage parlor!
                            And given that they [i]employ[/i] your kind, they'll probably have no quarrel serving you either.
                            Intrigued, you enter the building.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
