/**
 * Fight section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorFightFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preFail;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.fightFail;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var weaponPopup = global.kobold.inventory.createItemWithTooltip(weapon);
        var toReturn = `[p]
                            You never asked for this, but if it's a fight the human wants, a fight he'll get.
                            He may be bigger than you, he may be [b]stronger[/b] than you, and he may have a fancy long-reaching weapon,
                            but you are [b]far[/b] more determined to leave this place alive than the sickly human is to capture you.
                            Heck, he looks like he's halfway to hell already.
                            Time to deliver him to where he belongs.
                        [/p]
                        ${global.ui.condFail(`Attack + defence below 6`)}
                        ${global.ui.condFail(`Armor below 7`)}
                        [p]
                            You brandish your ${weaponPopup}, and drop into a combat stance.
                            The two of you circle around one another like predatory animals.
                            Then, Tychus makes the first move.
                            He swings his whip in a wide horizontal arc.
                            Despite your best efforts, you [b]fail[/b] to block the attack.
                            The leather cord snags you from the side,
                            snapping around your body, the steel tip [b]digging[/b] into your back,
                            burying in between two ligaments of your spine.
                        [/p]
                        [p]
                            You [b]scream[/b] out in pain, your spinal cord feeling as though it's completely [b]severed[/b]!
                            You let go of your weapon, dropping to your knees, and then crumpling to the floor.
                            You panic, thinking he [b]crippled[/b] you!
                            [b]You can't move[/b], no matter how much you try!
                        [/p]
                        [p]
                            Luckily, the sensation proves temporary.
                            By the time you regain the ability to rise to your feet, however, the fight is already long over.
                            Tychus has kicked your weapon to the side, and with you still struggling to move, he easily grabs you by your tail.
                            The human coarsely lifts you up off the ground and slings you over his shoulder like a piece of [b]meat[/b].
                            You try to fight back, but you still have a hard time controlling your body.
                            The most you manage to do is struggle and squirm a little, not nearly enough to free yourself.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
