/**
 * Arrival section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NightTwoStage(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]
                            Arrival
                        [/st]
                        [p]
                            After a boring, uneventful trek, you finally arrive at the great walls of Varanar.
                            Home to thousands, if not tens of thousands, it is the single largest city outside of the neighbouring Dragon Empire.
                            The capital of humans, one of the most prominent trading hubs in the entire world, and a melting pot for all walks of life,
                            from rich and snobby noblemen, to humble, rundown [b]thieves[/b] like yourself.
                        [/p]
                        [p]
                            The sun may have gone down, but in the darkness,
                            the myriad of flickering torchlights illuminating the battlements high up above showcase how [b]incredibly[/b] well protected the city is.
                            Nothing short of a determined and well-prepared besieging [b]army[/b] could ever hope to take the walls of Varanar.
                            While you've been here before, you've never seen them at night.
                            You always assumed the battlements were [i]empty[/i], that they'd be manned solely during times of war.
                            These fortifications were impressive and imposing enough [i]without[/i] realizing that they are constantly staffed,
                            a dozen archers and crossbowmen probably betting on whether or not they can hit that tiny little kobold 
                            approaching the gates at this very instant.
                        [/p]
                        [p]
                            While kobolds are generally [i]tolerated[/i] in public, there are no official laws protecting your kind.
                            You could be shot, stabbed or keelhauled in front of a crowd, and nobody would bat an eye.
                            The thing that frightens you the most is the fact that people can do [b]far worse[/b] things than simply hurting you, all according to law.
                            The guards rarely intervene, and when they do, you can be [b]darn[/b] sure that they [b]won't[/b] be picking [i]your[/i] side.
                        [/p]
                        [p]
                            But those are worries for later.
                            Right now, you focus on actually getting [b]in[/b] to the city proper.
                            The eastern gate, in front of which you stand, is currently clogged to the brim with people [b]leaving[/b] Varanar.
                            Must have been a long market day or something.
                            Leaning against a nearby road-fence, you decide to wait until the worst of the crowd has cleared.
                        [/p]
                        [p]
                            You had hoped you would only have to wait for a couple of minutes, but it takes almost an entire [b]hour[/b] for the huge mass of daytrippers,
                            marketeers, farmers, supply-running forest bandits and foreign trading caravans to siphon from the great city.
                            You pass the time by observing the huge variety of lifeforms on display.
                            Humans, horses, rodents, birds, cats both big and small, bears, reptiles and all sorts of canines walk on by.
                            Some carry wheelbarrows, others ride carts pulled by beasts of burden and a few are even rich enough to own their own chariots.
                        [/p]
                        [p]
                            Outside of a single kobold asking for directions, nobody really pays you much mind.
                            As the crowd slowly disperses in all directions of the land, you hop off of the fence, and proceed towards the gate.
                            While passing through the wall-opening, you instinctively gaze upwards at the portcullis,
                            ready to jump out of the way should it budge even an inch.
                            Luckily, this time at least, you are spared the wrath of the suspended metal.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.arrival.continued() ? "disabled" : "";
        var isSelected = ctrl.arrival.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.arrival.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        global.ui.applyTheme("varanar_night");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.arrival.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        next.registerListeners();

        if (ctrl.arrival.continued()) {
            return;
        }

        registerNextListener();
    };
}
