

// SCENE CaravanConfinement

// scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakFail.js

/**
 * Break section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBreakFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]weak[/i].
                            Old and ragged.
                            It's probably spent [b]years[/b] withering away on the outside of this very cart.
                            You think you might be able to [b]break[/b] it, if you try hard enough.
                        [/p]
                        [p]
                            With all of your strength, you pull and you tug at your restraints, testing the limits of the rope.
                            For nearly half an hour, you strenuously attempt to break your bonds.
                            Alas, the rope seems stronger than you anticipated.
                            It's tied too low for you to reach with your claws, and you can't seem to rip it through sheer strength alone.
                            Realizing your attempt at escaping is an exercise in futility, you cease your incessant struggling.
                        [/p]
                        ${global.ui.condFail(`Strength below 6`)}
                        [p]
                            While you didn't manage to exactly [i]break[/i] your bonds,
                            it feels as though the mere act of [i]trying[/i] alone has strengthened your arms.
                            While not exactly powertraining, the botched breakout has left you feeling a bit more [i]powerful[/i].
                        [/p]
                        [p]
                            After such an exerting effort, you slowly drift to sleep.
                            You get the feeling you'll be needing every ounce of energy you can scrape together to survive the coming day.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.breakFail.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakFail.js

// scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakSucceedContinue.js

/**
 * End section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBreakSucceedContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.knockedOut = true;
        var toReturn = `[p]
                            After caressing your wrists for a few moments,
                            slightly easing the pain of the minor rope burn you sustained while struggling to break your bonds,
                            you rise to your feet within the cell-like wagon.
                            Bad idea.
                        [/p]
                        [p]
                            The equine guard stationed outside of your cart just so happened to be leering inside of your confined area the moment you decided to stand upright.
                            Noticing your unbound hands, he draws a hefty-looking ${global.kobold.inventory.createItemWithTooltip(new Club())} from his belt.
                            For a moment, he stares at you, and you stare at him.
                            It takes a few seconds for you to register the fact that you've been caught.
                            Then, panic begins to settle in.
                        [/p]
                        [p]
                            The horse-sentry calmly walks over to the cart's single door.
                            He unlocks and opens it.
                            This is your chance.
                            Your one shot.
                            If you can get past him, you can escape into the wilderness, and regain your freedom!
                        [/p]
                        [p]
                            Alas, instead of attacking the horse, bolting past him, reasoning with him or even [b]seducing[/b] him,
                            your indecisive mind causes your body to freeze up in fright.
                            Instead of making a heroic getaway, you cower in fear, like a whelp that knows it [b]fucked up[/b].
                            Still, the equine shows no mercy.
                            He throws an overhead swing with his ${global.kobold.inventory.createItemWithTooltip(new Club())},
                            the wood crashing against the top of your head.
                        [/p]
                        [p]
                            You hear something [b]crack[/b].
                            You doubt it's the wood.
                            Your vision goes black.
                            You slump down onto the floor, knocked unconscious in a single blow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.breakSucceedContinue.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakSucceedContinue.js

// scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakSucceed.js

/**
 * Break section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBreakSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementBreakSucceedContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.escapedBindings = true;
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]weak[/i].
                            Old and ragged.
                            It's probably spent [b]years[/b] withering away on the outside of this very cart.
                            You think you might be able to [b]break[/b] it, if you try hard enough.
                        [/p]
                        [p]
                            With all of your strength, you pull and you tug at your restraints, testing the limits of the rope.
                            For nearly half an hour, you strenuously attempt to break your bonds.
                            Right as you are about to give up hope, you can feel a single [i]fiber[/i] of the rope spring loose,
                            torn due to constant stress.
                            The cord is weakened by just a very little, but that smidgen of integrity-loss spurs you to continue your incessant struggling.
                        [/p]
                        ${global.ui.condSucc(`Strength greater than 5`)}
                        [p]
                            It seems as though that, with a single strand loosened, the cord becomes far easier to rip apart.
                            Every time you attempt to tug your wrists apart, a new string pops loose.
                            Slowly, but surely, the rope thins, more and more of it snapping with every yank,
                            until finally it has grown weak enough for you to break out completely.
                            With one last mighty show of force, you tear your wrists free from their bondage, the rope audibly snapping.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.breakSucceed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreakSucceed.js

// scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreak.js

/**
 * Break section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBreak(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.BREAK;
    var reqController = ctrl.cart;

    var toFail = new CaravanConfinementBreakFail(ctrl);
    var toSuccess = new CaravanConfinementBreakSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.strength() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\break\CaravanConfinementBreak.js

// scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipFail.js

/**
 * Slip section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementSlipFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]loose[/i].
                            Improperly tied.
                            The wolf probably thought you weren't even going to bother trying to escape.
                            He was wrong.
                        [/p]
                        [p]
                            You wriggle and rotate your wrists,
                            you try to roll the rope alongside your scales by rubbing it against the floor,
                            and you contort your hands in ways you didn't even know were possible.
                            Almost succeeding to free yourself, you break out every single last trick in the book in an attempt to regain your freedom.
                            For nearly half an hour, you strenuously attempt to abscond your bonds.
                            Alas, the rope seems to be far more secure than you anticipated.
                            It's tied too low for you to reach with your claws, and you can't seem to rip it through sheer wrist-motion alone.
                            Realizing your attempt at escaping is an exercise in futility, you cease your incessant struggling.
                        [/p]
                        ${global.ui.condFail(`Agility below 6`)}
                        [p]
                            While you didn't manage to exactly [i]break[/i] your bonds,
                            it feels as though the mere act of [i]trying[/i] alone has made your arms a bit more flexible.
                            While not exactly a stretching drill, the botched breakout has left you feeling a bit more [i]agile[/i].
                        [/p]
                        [p]
                            After such a tiring effort, you slowly drift to sleep.
                            It's been a long day, and you get the feeling you'll be needing every ounce of energy you can scrape together to make it through tomorrow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.slipFail.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipFail.js

// scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipSucceedContinue.js

/**
 * End section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementSlipSucceedContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.knockedOut = true;
        var toReturn = `[p]
                            After caressing your wrists for a few moments,
                            slightly easing the pain of the minor rope burn you sustained while struggling to break your bonds,
                            you rise to your feet within the cell-like wagon.
                            Bad idea.
                        [/p]
                        [p]
                            The equine guard stationed outside of your cart just so happened to be leering inside of your confined area the moment you decided to stand upright.
                            Noticing your unbound hands, he draws a hefty-looking ${global.kobold.inventory.createItemWithTooltip(new Club())} from his belt.
                            For a moment, he stares at you, and you stare at him.
                            It takes a few seconds for you to register the fact that you've been caught.
                            Then, panic begins to settle in.
                        [/p]
                        [p]
                            The horse-sentry calmly walks over to the cart's single door.
                            He unlocks and opens it.
                            This is your chance.
                            Your one shot.
                            If you can get past him, you can escape into the wilderness, and regain your freedom!
                        [/p]
                        [p]
                            Alas, instead of attacking the horse, bolting past him, reasoning with him or even [b]seducing[/b] him,
                            your indecisive mind causes your body to freeze up in fright.
                            Instead of making a heroic getaway, you cower in fear, like a whelp that knows it [b]fucked up[/b].
                            Still, the equine shows no mercy.
                            He throws an overhead swing with his ${global.kobold.inventory.createItemWithTooltip(new Club())},
                            the wood crashing against the top of your head.
                        [/p]
                        [p]
                            You hear something [b]crack[/b].
                            You doubt it's the wood.
                            Your vision goes black.
                            You slump down onto the floor, knocked unconscious in a single blow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.slipSucceedContinue.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipSucceedContinue.js

// scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipSucceed.js

/**
 * Slip section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementSlipSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementSlipSucceedContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.escapedBindings = true;
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]loose[/i].
                            Improperly tied.
                            The wolf probably thought you weren't even going to bother trying to escape.
                            He was wrong.
                        [/p]
                        [p]
                            You wriggle and rotate your wrists,
                            you try to roll the rope alongside your scales by rubbing it against the floor,
                            and you contort your hands in ways you didn't even know were possible.
                            Almost succeeding to free yourself, you break out every single last trick in the book in an attempt to regain your freedom.
                            For nearly half an hour, you strenuously attempt to abscond your bonds.
                            Just as you were about to give up, one last attempt at rubbing against the floor finally seems to pay off!
                            The rope rolls just a little higher up, closer to your actual hands.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 5`)}
                        [p]
                            Encouraged by the sense of progress, you reach down with your fingers.
                            While you can't quite escape your bindings yet, the rope is now in range of your claws!
                            You arduously begin to [i]file[/i] away at the cord, cutting through it with short, hasty finger-motions.
                            After another couple of minutes, the rope suddenly [b]snaps[/b] in half, freeing you from your bonds.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.slipSucceed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlipSucceed.js

// scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlip.js

/**
 * Break section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementSlip(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.SLIP;
    var reqController = ctrl.cart;

    var toFail = new CaravanConfinementSlipFail(ctrl);
    var toSuccess = new CaravanConfinementSlipSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.agility() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\slip\CaravanConfinementSlip.js

// scenes\Enslavement\CaravanConfinement\cart\bang\CaravanConfinementBang.js

/**
 * Bang section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBang(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.BANG;
    var reqController = ctrl.cart;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The wood the floor of this cart is made out of looks kind of [i]weak[/i].
                            It's seen better days, and you doubt it was very sturdy to begin with.
                            You figure you might be able to break it.
                        [/p]
                        [p]
                            But with what?
                            Your arms are tied, and laying on the ground, your legs aren't of much use.
                            If you get up, a guard might see what you're doing.
                            That leaves only one option: your head.
                        [/p]
                        [p]
                            You sigh loudly.
                            You [b]need[/b] to get out of here, and this is the only way you're going to accomplish that.
                            You slowly lift your head off the floor, before [b]bashing[/b] it against the frail wood.
                            You barely refrain from yelping out in pain, tears forming at the corners of your eyes.
                            Your head feels like it cracked open as much as the wood did, if not more.
                        [/p]
                        [p]
                            While hurting, you need to press on.
                            You've already taken the first step.
                            You're already [b]in pain[/b].
                            It'd be an outright [b]waste[/b] to stop now.
                            Gritting your teeth, your rear your head back once more.
                            Again, you [b]slam[/b] it downwards, your already bruised forehead feeling like it's about to [b]explode[/b].
                            The wood creaks, but it does not crack.
                            Just [b]once more[/b].
                        [/p]
                        [p]
                            Your teeth chattering, you lift your head for a third time.
                            You close your eyes.
                            It hurts [b]so much[/b].
                            Your breathing is ragged.
                            You [b]need[/b] to do this.
                            Swallowing deeply, you [b]bash[/b] the floor with your forehead a third time.
                        [/p]
                        [p]
                            A loud [b]crack[/b] resonates throughout the cart.
                            You open your eyes.
                            Blood stains the floor, which seems to have held, despite your best efforts.
                            That must mean that thing that cracked must have been...your head?
                        [/p]
                        [p]
                            Suddenly, your sight goes blurry.
                            Soon after, it fades to black.
                            You slump down lifelessly onto the wooden wagon floor.
                            Your breathing slows to a crawl.
                            You pass out, the last thought on your mind being that
                            perhaps this wasn't the brightest idea after all.
                        [/p]`;

        return global.parser.parse(toReturn);
    }
    
    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.bang.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\bang\CaravanConfinementBang.js

// scenes\Enslavement\CaravanConfinement\cart\count\CaravanConfinementCount.js

/**
 * Count section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementCount(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.COUNT;
    var reqController = ctrl.cart;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With nothing better to do, you decide to pass the time by counting the iron bars lining your [i]mobile cell[/i].
                            Starting at the left-hand side, you count:
                        [/p]
                        [p]
                            [i]One...two...three...four...five...six...seven...[/i]
                            You yawn.
                            [i]Eight...nine...ten...eleven...twelve...[/i]
                            Your eyelids are growing heavy.
                            [i]Thirteen...fourteen...fifteen...[/i]
                            Slowly, but steadily, your counting stops.
                            Your eyes close, and you drift away into sweet unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.count.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\count\CaravanConfinementCount.js

// scenes\Enslavement\CaravanConfinement\cart\gaze\CaravanConfinementGaze.js

/**
 * Gaze section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementGaze(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.GAZE;
    var reqController = ctrl.cart;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With nothing better to do, you decide to pass the time by gazing at the stars,
                            which you can see clearly through the metal bars of your [i]cell[/i].
                            You've always been fascinated with celestial things.
                            Those twinkling torches high up in the night sky have been the object of your dreams for many years now.
                        [/p]
                        [p]
                            You roll onto your back, and stare into the void.
                            The pitch blackness dotted with sparkling stars is soothing and easing.
                            You've been through [b]hell[/b] today.
                            You're glad to finally have a quiet moment in which you can [i]unwind[/i] and [b]think[/b] about things.
                        [/p]
                        [p]
                            Sure, you've been captured, but this isn't the first time you've botched a heist.
                            You've never actually been in a [i]cell[/i] before, though.
                            In the past, you've always managed to slip out of the greasy palms of whatever guardsman or vigilante caught you [i]before[/i] getting imprisoned.
                            Oh well, first time for everything.
                            You'll find a way to escape yet.
                            Just need to wait for the perfect opportunity to come along.
                        [/p]
                        [p]
                            You begin to relax, your eyelids growing more weary with every passing second.
                            Suddenly, it seems as though your cell is illuminated a little bit more than usual.
                            Like the stars themselves are shining their light down upon you.
                            After a few moments, the sudden brightness fades, leaving nothing but a lasting impression.
                            Come to think of it, your eyes weren't even open when it happened.
                            Perhaps you were already dreaming.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.gaze.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\gaze\CaravanConfinementGaze.js

// scenes\Enslavement\CaravanConfinement\cart\talk\CaravanConfinementTalk.js

/**
 * Talk section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementTalk(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.TALK;
    var reqController = ctrl.cart;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With nothing better to do, you decide to pass the time by striking a conversation with the guard outside of your cell.
                            You whisper to him, yet there is no response.
                            Raising your voice a little, you casually begin to talk about how you're having a [b]terrible[/b] day.
                            You ask him how [b]his[/b] day is going.
                            There is no response.
                        [/p]
                        [p]
                            Taking his silence for attentivity,
                            you begin to chat about that one time you caught a [b]really[/b] large fish out of the river, with your bare hands!
                            You ask him if he's ever gone fishing.
                            You've seen the way humans and most anthros fish -- using poles and stuff.
                            That's not the way kobolds do it.
                            You just kind of jump in and try to [i]grab[/i] one.
                            You guess that would be kind of hard for someone lacking [i]claws[/i].
                        [/p]
                        [p]
                            That's not to say you wouldn't give the human method a try.
                            It seems relaxing, just sitting in a small boat, or at the river shore, waiting for something to tug on your line.
                            But then again, in [i]this[/i] forest, you doubt you'd be alone for long before attracting some [i]unwanted company[/i].
                            Besides, that fish you told him about?
                            Yeah, you got halfway through cooking that over a campfire before a gang jumped out of the bushes and made you run for your life.
                            That was the last time you tried to cook a catch instead of eating it raw.
                        [/p]
                        [p]
                            You ask the man whether or not he likes to eat fish.
                            You personally prefer meat.
                            You haven't had any proper meat in [b]ages[/b], though.
                            The stuff you usually eat is refuse left by [i]things[/i] [b]bigger[/b] and [b]meaner[/b] than you are.
                            Sometimes, hunters from the city don't even bother taking home their catch.
                            All the better for you, of course.
                        [/p]
                        [p]
                            The person you're talking to still hasn't said a single word.
                            You're starting to think they either [b]can't hear[/b] you,
                            or maybe they're simply not interested in talking to an annoying little kobold they're forced to [b]babysit[/b].
                            You awkwardly say it's been nice talking to them, whoever they are, and then you stop speaking to the wooden wall in front of you.
                        [/p]
                        [p]
                            Truth be told, this actually [b]was[/b] a pleasant experience, regardless of whether they even [b]heard you[/b] or not.
                            You got to reflect on some things and you remembered some pleasant memories.
                            With those in mind, you roll onto your back, close your eyes, and try to get some sleep.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.talk.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\CaravanConfinement\cart\talk\CaravanConfinementTalk.js

// scenes\Enslavement\CaravanConfinement\cart\CaravanConfinementCart.js

/**
 * Cart section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementCart(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.postTight;
    var subController = ctrl.cart;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";
    var fifthId = arguments.callee.name + "ButtonFive";
    var sixthId = arguments.callee.name + "ButtonSix";

    var firstNext = new CaravanConfinementBreak(ctrl);
    var secondNext = new CaravanConfinementSlip(ctrl);
    var thirdNext = new CaravanConfinementBang(ctrl);
    var fourthNext = new CaravanConfinementCount(ctrl);
    var fifthNext = new CaravanConfinementGaze(ctrl);
    var sixthNext = new CaravanConfinementTalk(ctrl);

    var firstChoice = CaravanConfinementCartChoice.BREAK;
    var secondChoice = CaravanConfinementCartChoice.SLIP;
    var thirdChoice = CaravanConfinementCartChoice.BANG;
    var fourthChoice = CaravanConfinementCartChoice.COUNT;
    var fifthChoice = CaravanConfinementCartChoice.GAZE;
    var sixthChoice = CaravanConfinementCartChoice.TALK;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var hole = "rear end";
        if (male && fucked) {
            hole = "cockslit";
        }
        if (!male && !fucked) {
            hole = "cunt";
        }
        var toReturn = `[p]
                            Satisfied with his [i]discovery[/i], the caravan master removes his finger from your ${hole}, and rises to his feet.
                            "[color=brown]That's all I needed to know.
                            Shove'em in one of the empty carts near the back.
                            Station an extra watchman to ensure our little [i]guest[/i] stays put during the night.
                            We'll split off from the main caravan once we get close enough to the city
                            for the guards to ensure your men won't go running off with the gold.[/color]"
                        [/p]
                        [p]
                            Fenrir, or so the human called him earlier, scoffs at the notion that his group would break a bargain without being told to do so.
                            After a bit of uninteresting back and forth idle chatter,
                            the wolf grabs you by the collar, much like before,
                            and sets off for the rear end of the convoy,
                            tugging you along with.
                        [/p]
                        [p]
                            Arriving at the second-to-last transport carriage, the canine comes to a halt.
                            "[color=gblue]This is your stop.[/color]" he speaks, unlocking and opening the cart.
                            Grabbing a piece of rope hanging off the side of the vehicle, the buff lupine deftly ties your wrists together behind your back.
                            You don't even bother [i]trying[/i] to resist.
                            Your hands safely secured, the wolf casually lifts you up off the ground.
                            In a surprisingly gentle fashion, he rests your body down on the wooden carriage floor.
                        [/p]
                        [p]
                            "[color=gblue]Try to get some sleep.
                            Wouldn't want you to look weary during the auction tomorrow, now would we?
                            Remember: if you don't sell, your ass is [b]mine[/b].
                            And I share [b]everything[/b] with the rest of my crew.[/color]"
                            His mixture between a [i]threat[/i] and a sarcastic [i]pseudo-invitation[/i] shared,
                            the wolf closes the cart's sole door, granting you some peace and quiet after a long and arduous day.
                        [/p]
                        [p]
                            You're tired and exhausted, both mentally and physically, but you think you have enough energy left for one final act before going to sleep.
                            Outside of the cart, you hear footsteps.
                            Probably your personal guard, here to ensure you won't be [i]leaving[/i].
                            As if you could escape with your hands tied.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 190px;">Break bindings</button>`;

        var tooltip = global.parser.parse(`Attempt to break the rope holding your hands together.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 190px;">Slip from bindings</button>`;

        var tooltip = global.parser.parse(`Try to remove your hands from the rope binding them together.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 190px;">Use your head</button>`;

        var tooltip = global.parser.parse(`Wantonly bang your forehead against the side of the cart. Maybe the wood'll break.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 190px;">Count bars</button>`;

        var tooltip = global.parser.parse(`Count your makeshift cell's iron bars to pass the time.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFifthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fifthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fifthId}" ${disabled} style="width: 190px;">Stargaze</button>`;

        var tooltip = global.parser.parse(`You can see some of the stars through the cart's small, barred windows. Let the night sky calm you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSixthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === sixthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${sixthId}" ${disabled} style="width: 190px;">Talk</button>`;

        var tooltip = global.parser.parse(`Strike a conversation with the sentry posted outside of your prison.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildFourthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFifthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSixthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId), $("#" + fifthId), $("#" + sixthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFifthListener() {
        $("#" + fifthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fifthChoice);
            loadNextPart(fifthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSixthListener() {
        $("#" + sixthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(sixthChoice);
            loadNextPart(sixthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        part += fifthNext.build();
        part += sixthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();
        fifthNext.registerListeners();
        sixthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
        registerFifthListener();
        registerSixthListener();
    };
}

var CaravanConfinementCartChoice = {
    BREAK: 1,
    SLIP: 2,
    BANG: 3,
    COUNT: 4,
    GAZE: 5,
    TALK: 6
};

// END scenes\Enslavement\CaravanConfinement\cart\CaravanConfinementCart.js

// scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementClaw.js

/**
 * Tightness section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementClaw(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementTightnessChoice.CLAW;
    var reqController = ctrl.tight;
    var subController = ctrl.postTight;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementCart(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var toReturn = `[p]
                            You aren't going to let this filthy [b]slaver[/b] touch you!
                            You'd rather [b]get your neck snapped[/b] by the wolf standing behind you than let some disgusting,
                            mean, [b]rude[/b] human lay his hands upon you!
                            As he reaches for your groin, you raise your arm threateningly, preparing to [b]maim[/b] his face with your sharp claws.
                            Mere moments before you manage to bring your natural weapons to bear, your wrist is grabbed from behind by a powerful, furred hand.
                        [/p]
                        [p]
                            The wolf, still holding your tail, restrains you, preventing you from striking your target.
                            You aren't stopped that easily, though.
                            You lift your [i]other[/i] hand, determined to [b]hurt[/b] the caravan master.
                            A second time, however, you are interrupted mid-strike.
                        [/p]
                        [p]
                            Rather than taking hold of your other wrist as well, the canine chooses to simply [b]squeeze[/b] the small scaly arm already in his grasp.
                            You wince in pain, the bandit's powerful grip making it [b]very[/b] clear that he could snap your bones like [b]twigs[/b].
                            "[color=gblue][b]Don't[/b].[/color]" he states, and nothing more.
                            Whimpering and whining, you meekly lower your free hand once more, and relent to the humiliating inspection.
                        [/p]
                        [p]
                            Tears form at the corners of your eyes, not from pain, but from [b]shame[/b].
                            Shame that you are going to [b]let this happen[/b],
                            instead of struggling so hard they're forced to beat you to a [b]bloody pulp[/b] before being able to check your loins.
                        [/p]
                        [p]
                            A knight would fight to the very end before suffering indignation at the hands of ${male ? `his` : `her`} captors.
                            But, despite your best hopes and dreams, you are no knight.
                            You are a [b]thief[/b], and now a [b]slave[/b].
                            A [b]coward[/b], scared of getting hurt.
                            A weakling that yields in the face of adversity, instead of rising beyond and above.
                        [/p]
                        [p]
                            If you were stronger, more agile, smarter perhaps, there might have been a way out of this situation.
                            But for a frail kobold like yourself, all you can do is resign to your fate,
                            and hope that the human kneeling before you will stay true to his word instead of taking things [i]one step further[/i].
                        [/p]`;

        if (fucked && male) {
            toReturn += `[p]
                            As your tears drip to the ground, the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it makes its way towards your rear, rubbing over your still-sensitive butthole.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the front, pressing it against your virginal cockslit.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he slips the tip of the chubby digit inside of your warm slit,
                            testing the tightness of an orifice that was never meant to be fucked.
                        [/p]
                        [p]
                            "[color=brown]You could pass for a maiden if there wasn't a dick in there.[/color]" the caravan master speaks,
                            elliciting a chuckle from the wolf.
                            "[color=gblue]Well, now I know which hole I'll be fucking if you don't sell, kobold.[/color]"
                        [/p]`;
        } else if (fucked && !male) {
            toReturn += `[p]
                            As your tears drip to the ground, the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it travels along the length of your slit, parting your folds ever so slightly.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the rear, pressing it against your virginal tailhole.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he slips the tip of the chubby digit inside of your butt,
                            testing the tightness of an orifice that was never meant to be fucked.
                        [/p]
                        [p]
                            "[color=brown]Tighter than a monk's lips.[/color]" the caravan master speaks,
                            elliciting a chuckle from the wolf.
                            "[color=gblue]Well, now I know which hole I'll be fucking if you don't sell, kobold.[/color]"
                        [/p]`;
        } else if (!fucked && male) {
            toReturn += `[p]
                            As your tears drip to the ground, the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It makes its way towards your rear, rubbing over your virginal butthole.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he presses the tip of his chubby finger inside of your butt,
                            testing the tightness of a virginal kobold.
                        [/p]
                        [p]
                            "[color=brown]Looks like he wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]A virgin kobold, a rarity for sure.
                            I have no doubt you'll sell well.[/color]"
                            The wolf chuckles, quickly adding:
                            "[color=gblue]And if you don't, you won't be a virgin for much longer.[/color]"
                            The canine gives a teasing thrust from behind, bumping his clothed groin against the back of your head.
                        [/p]`;
        } else {
            toReturn += `[p]
                            As your tears drip to the ground, the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It travls along the length of your slit, parting your folds ever so slightly.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he presses the tip of his chubby finger inside of your cunt,
                            testing the tightness of a virginal kobold.
                        [/p]
                        [p]
                            "[color=brown]Looks like she wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]A virgin kobold, a rarity for sure.
                            I have no doubt you'll sell well.[/color]"
                            The wolf chuckles, quickly adding:
                            "[color=gblue]And if you don't, you won't be a virgin for much longer.[/color]"
                            The canine gives a teasing thrust from behind, bumping his clothed groin against the back of your head.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementClaw.js

// scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementStandStill.js

/**
 * Tightness section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementStandStill(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementTightnessChoice.STILL;
    var reqController = ctrl.tight;
    var subController = ctrl.postTight;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementCart(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var toReturn = `[p]
                            You don't want to let this filthy [b]slaver[/b] touch you, but you don't have much of a choice, either.
                            The wolf standing behind you could easily [b]snap your neck[/b] if you so much as [b]tried[/b] to make a move.
                            As the caravan master reaches for your groin, you consider raising your arm threateningly, but ultimately decide to just [i]let this happen[/i],
                            hoping it'll be over soon, that he won't decide to take things [i]one step further[/i].
                        [/p]`;

        if (fucked && male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it makes its way towards your rear, rubbing over your still-sensitive butthole.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the front, pressing it against your virginal cockslit.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he slips the tip of the chubby digit inside of your warm slit,
                            testing the tightness of an orifice that was never meant to be fucked.
                        [/p]
                        [p]
                            "[color=brown]You could pass for a maiden if there wasn't a dick in there.[/color]" the caravan master speaks,
                            elliciting a chuckle from the wolf.
                            "[color=gblue]Well, now I know which hole I'll be fucking if you don't sell, kobold.[/color]"
                        [/p]`;
        } else if (fucked && !male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it travels along the length of your slit, parting your folds ever so slightly.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the rear, pressing it against your virginal tailhole.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he slips the tip of the chubby digit inside of your butt,
                            testing the tightness of an orifice that was never meant to be fucked.
                        [/p]
                        [p]
                            "[color=brown]Tighter than a monk's lips.[/color]" the caravan master speaks,
                            elliciting a chuckle from the wolf.
                            "[color=gblue]Well, now I know which hole I'll be fucking if you don't sell, kobold.[/color]"
                        [/p]`;
        } else if (!fucked && male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It makes its way towards your rear, rubbing over your virginal butthole.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he presses the tip of his chubby finger inside of your butt,
                            testing the tightness of a virginal kobold.
                        [/p]
                        [p]
                            "[color=brown]Looks like he wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]A virgin kobold, a rarity for sure.
                            I have no doubt you'll sell well.[/color]"
                            The wolf chuckles, quickly adding:
                            "[color=gblue]And if you don't, you won't be a virgin for much longer.[/color]"
                            The canine gives a teasing thrust from behind, bumping his clothed groin against the back of your head.
                        [/p]`;
        } else {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It travels along the length of your slit, parting your folds ever so slightly.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            Then, he presses the tip of his chubby finger inside of your cunt,
                            testing the tightness of a virginal kobold.
                        [/p]
                        [p]
                            "[color=brown]Looks like she wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]A virgin kobold, a rarity for sure.
                            I have no doubt you'll sell well.[/color]"
                            The wolf chuckles, quickly adding:
                            "[color=gblue]And if you don't, you won't be a virgin for much longer.[/color]"
                            The canine gives a teasing thrust from behind, bumping his clothed groin against the back of your head.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementStandStill.js

// scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementMoan.js

/**
 * Tightness section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementMoan(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementTightnessChoice.MOAN;
    var reqController = ctrl.tight;
    var subController = ctrl.postTight;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementCart(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var toReturn = `[p]
                            While you aren't keen on getting touched by this filthy [b]slaver[/b],
                            you feel like this might be a good time to [i]play along[/i],
                            to show that you're a [b]good ${male ? `boy` : `girl`}[/b],
                            and maybe earn some favor points from either of the men in the process.
                            After all, if you [i]act[/i] the part of a slave,
                            then they'll have no reason to hurt or mistreat you.
                            If you humor them, they might eventually choose to [i]let you go[/i], or so you hope.
                            And even if they don't, at the very least you'll be treated marginally better if you do as they say instead of fighting them every step of the way.
                        [/p]`;

        if (fucked && male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it makes its way towards your rear, rubbing over your still-sensitive butthole.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the front, pressing it against your virginal cockslit.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            To his confusion, his smirk is met with an anticipating grin.
                            As he slips the tip of the chubby digit inside of your warm slit,
                            testing the tightness of an orifice that was never meant to be fucked,
                            you let out a small, pleased sigh, like a [b]cheap whore[/b] trying to entice a client.
                        [/p]
                        [p]
                            "[color=brown]Are you sure you're not a [b]girl[/b]?[/color]" the caravan master asks,
                            elliciting a chuckle from the wolf.
                            "[color=brown]A finger in your cockslit can't feel [b]that[/b] good.[/color]"
                            The canine interrupts:
                            "[color=gblue]I don't know. A thumb up my sheath always gets me going.[/color]"
                            The human seems unamused.
                        [/p]`;
        } else if (fucked && !male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            First, it travels along the length of your slit, parting your folds ever so slightly.
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body won't be a prominent selling point,
                            at least not for a couple of days more, when it'll regain its tightness.
                        [/p]
                        [p]
                            He sighs loudly, before moving his finger a bit more to the rear, pressing it against your virginal tailhole.
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            To his confusion, his smirk is met with an anticipating grin.
                            As he slips the tip of the chubby digit inside of your ass,
                            testing the tightness of an orifice that was never meant to be fucked,
                            you let out a small, pleased sigh, like a [b]cheap whore[/b] trying to entice a client.
                        [/p]
                        [p]
                            "[color=brown]A real [b]buttslut[/b], huh?[/color]" the caravan master comments,
                            elliciting a chuckle from the wolf.
                            "[color=gblue]Well, now I know which hole I'll be fucking if you don't sell, kobold.[/color]"
                        [/p]`;
        } else if (!fucked && male) {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It makes its way towards your rear, rubbing over your virginal butthole.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            To his confusion, his smirk is met with an anticipating grin.
                            As he presses the tip of his chubby finger inside of your butt,
                            testing the tightness of a virginal kobold,
                            you let out a small, pleased sigh, like a [b]cheap whore[/b] trying to entice a client.
                        [/p]
                        [p]
                            "[color=brown]Looks like he wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]An eager virgin kobold slave.
                            I have no doubt you'll sell well.[/color]"
                            The wolf grunts dejectedly.
                            "[color=gblue]If you're so lusty, why didn't you let me do you in the forest?[/color]"
                            Clearing his throat, the human answers for you:
                            "[color=brown]Be glad that he didn't.
                            Now he's worth twice as much.[/color]"
                        [/p]`;
        } else {
            toReturn += `[p]
                            Noticing your lack of [i]resistance[/i], the caravan master begins his [i]inspection[/i].
                            A single, probing finger slides over the scales of your nether region.
                            It travels along the length of your slit, parting your folds ever so slightly.
                        [/p]
                        [p]
                            Even without slipping the digit inside,
                            the caravan master can clearly tell that this part of your body could be a prominent selling point,
                            but he isn't content with just [b]touching[/b].
                            The human stares directly into your eyes.
                            A small smirk forms on his face.
                            To his confusion, his smirk is met with an anticipating grin.
                            As he presses the tip of his chubby finger inside of your cunt,
                            testing the tightness of a virginal kobold,
                            you let out a small, pleased sigh, like a [b]cheap whore[/b] trying to entice a client.
                        [/p]
                        [p]
                            "[color=brown]Looks like she wasn't lying after all.[/color]" the caravan master speaks.
                            "[color=brown]An eager virgin kobold slave.
                            I have no doubt you'll sell well.[/color]"
                            The wolf grunts dejectedly.
                            "[color=gblue]If you're so lusty, why didn't you let me do you in the forest?[/color]"
                            Clearing his throat, the human answers for you:
                            "[color=brown]Be glad that she didn't.
                            Now she's worth twice as much.[/color]"
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementMoan.js

// scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementTightness.js

/**
 * Tight section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementTightness(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.postMouth;
    var subController = ctrl.tight;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new CaravanConfinementClaw(ctrl);
    var secondNext = new CaravanConfinementStandStill(ctrl);
    var thirdNext = new CaravanConfinementMoan(ctrl);

    var firstChoice = CaravanConfinementTightnessChoice.CLAW;
    var secondChoice = CaravanConfinementTightnessChoice.STILL;
    var thirdChoice = CaravanConfinementTightnessChoice.MOAN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var toReturn = `[p]
                            "[color=brown]Anyway, there's one more thing we need to take a look at.[/color]"
                            The caravan master gives the canine a small nod.
                            The wolf, who seemingly understands the human's intentions, steps behind you.
                            Grabbing your tail, the strong lupine [b]yanks[/b] it out from in between your legs, exposing your loins.
                            The expert in slavery, meanwhile, drops to his knees, coming face-to-face with you.
                            [i]He smells.[/i]
                        [/p]`;
        
        if(fucked) {
            toReturn += `[p]
                            The man forcibly parts your thighs with one of his burly hands.
                            "[color=brown]Damnit, Fenrir!
                            Do you [b]really[/b] have to [b]fuck[/b] everything you get your filthy hands on?![/color]"
                            You hear the canine behind you chuckle.
                            "[color=gblue]What can I say?
                            I'm a wolf.
                            That's what we do.
                            We [b]fuck[/b] things.[/color]"
                            The human seems unimpressed by the bandit's lackluster explanation.
                            "[color=gblue]Besides, that nun in the village we passed was practically [b]begging[/b] for it.[/color]"
                        [/p]
                        [p]
                            "[color=brown]Should have brought [b]her[/b] back to the caravan instead of this scaly [i]thief[/i].
                            Let's hope the [i]other[/i] hole is still tight enough to attract a couple of potential buyers.
                            A good mouth alone won't draw in the [i]perverts[/i], and those are the people who [b]really[/b] [i]jack up[/i] the price.[/color]"
                        [/p]`;
        } else {
            toReturn += `[p]
                            The man forcibly parts your thighs with one of his burly hands.
                            "[color=gblue]It said it was a virgin, back when I caught it.[/color]" the wolf shares.
                            The human inquisitively raises an eyebrow.
                            "[color=brown]A virgin kobold?
                            And you [b]bought[/b] that lie?
                            Come on, Fenrir, I thought you were smarter than that.[/color]"
                            The canine squeezes your tail, wordlessly threatening to harm you should you have [i]lied[/i] to him.
                            "[color=brown]Let's find out if we have an [b]honest thief[/b] or a [b]rotten apple[/b] on our hands.[/color]"
                        [/p]`;
        }
        
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Scratch him</button>`;

        var tooltip = global.parser.parse(`Claw at the human, hopefully dissuading him from probing your nether region.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Stand still</button>`;

        var tooltip = global.parser.parse(`Let the man do his thing. It'll be over a lot faster if you don't resist.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Moan</button>`;

        var tooltip = global.parser.parse(`Show him you know what a slave is to do when someone touches you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var CaravanConfinementTightnessChoice = {
    CLAW: 1,
    STILL: 2,
    MOAN: 3
};

// END scenes\Enslavement\CaravanConfinement\tight\CaravanConfinementTightness.js

// scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementBite.js

/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBite(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementMouthChoice.BITE;
    var reqController = ctrl.mouth;
    var subController = ctrl.postMouth;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementTightness(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You quickly snap your jaws, hoping to catch the tips of the human's fingers, but sadly,
                            you miss your goal, the caravan master's strategic finger-placement causing your teeth to barely [b]scrape[/b] against the edge of his skin.
                            Despite your bite missing its mark, the man still ends up retracting his hand from your mouth, probably in fear of your sharp fangs.
                            Victory!
                        [/p]
                        [p]
                            Alas, the smug smile that forms on your face is all too soon wiped away.
                            Using the very same hand you nearly bit, the human harshly [b]slaps[/b] the side of your face, with all of the strength in his beefy arm.
                            You yelp out in pain.
                            While you're still reeling from the slap, he grabs your throat, squeezing it shut, choking you for just long enough to get his message across:
                            "[color=brown]You filthy fucking [b]lizard[/b].
                            If I wasn't going to sell you, I'd knock out your teeth and shove them up your slit for that.
                            Now, you listen good.
                            I'm only going to say this [b]once[/b].
                            [b]Don't test my patience.[/b]
                            I'll skin you alive and make you eat your own [b]guts[/b] if you try to pull something like that again.[/color]"
                        [/p]
                        [p]
                            His words freshly burned into your oxygen-starved mind, the caravan master lets go of your neck.
                            You gasp for air, only barely managing to stay on your feet.
                            While you're busy recovering from asphyxiation, the man looks over the rest of your body.
                            "[color=brown]Some small cuts and bruises.
                            Nothing major.
                            I wouldn't call it [i]pristine[/i] condition, but good enough for sellin'.
                            Too bad about the shitty attitude, though.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementBite.js

// scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementTeeth.js

/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementTeeth(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementMouthChoice.TEETH;
    var reqController = ctrl.mouth;
    var subController = ctrl.postMouth;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementTightness(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You don't really want to [i]anger[/i] the man, but you don't feel comfortable with him probing around your mouth either.
                            Your keep your jaw closed, without actively [i]resisting[/i] the human's inspection.
                            He sighs, but he doesn't even [i]attempt[/i] to pry open your muzzle further.
                            Instead, he lowers his head to better gaze into your maw,
                            inspecting what little he can see of your gums, as well as your teeth, internally grading you like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Finished with his shallow inspection, the man removes his fingers from your muzzle.
                            "[color=brown]I didn't get a good look, but there aren't any apparent diseases.
                            Teeth might need some [b]filing[/b], but that's not [i]our[/i] job.
                            Lizard, next time I want to look in your mouth, you better [b]open up[/b] properly,
                            or I'll [b]hurt you[/b] until you do.
                            Got it?[/color]"
                            You don't bother dignifying his threat with a nod.
                            He knows darn well you heard him.
                        [/p]
                        [p]
                            Your maw graded, the caravan master runs his eyes along the rest your naked frame, examining you from top to bottom.
                            "[color=brown]Some small cuts and bruises.
                            Nothing major.
                            I wouldn't call it [i]pristine[/i] condition, but good enough for sellin'.
                            Attitude could use some adjusting, but some buyers like the ones that still have a little [i]spark[/i] to them.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementTeeth.js

// scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementCooperate.js

/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementCooperate(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementMouthChoice.COOPERATE;
    var reqController = ctrl.mouth;
    var subController = ctrl.postMouth;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementTightness(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var further = ctrl.name.get() === CaravanConfinementNameChoice.STATE;
        var toReturn = `[p]
                            Not wanting to anger your captors, you open your mouth wide.
                            The human seems pleased with your decision to cooperate, his stern visage somewhat relaxing${further ? ` further` : ``}.
                            "[color=brown]'Atta ${male ? "boy" : "girl"}.[/color]" he says, lowering his head to better gaze into your maw,
                            inspecting your gums, your teeth and your tongue, internally grading you like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Finished with his inspection, the man removes his fingers from your muzzle.
                            "[color=brown]No apparent diseases.
                            Mouth seems clean enough.
                            Teeth might need some [b]filing[/b], but that's not [i]our[/i] job.[/color]"
                        [/p]
                        [p]
                            Your maw graded, the caravan master runs his eyes along the rest your naked frame, examining you from top to bottom.
                            "[color=brown]Some small cuts and bruises.
                            Nothing major.
                            I wouldn't call it [i]pristine[/i] condition, but good enough for sellin'.
                            Looks like we might not have to roast you over the open fire after all, kobold.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementCooperate.js

// scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementMouth.js

/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementMouth(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.postName;
    var subController = ctrl.mouth;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new CaravanConfinementBite(ctrl);
    var secondNext = new CaravanConfinementTeeth(ctrl);
    var thirdNext = new CaravanConfinementCooperate(ctrl);

    var firstChoice = CaravanConfinementMouthChoice.BITE;
    var secondChoice = CaravanConfinementMouthChoice.TEETH;
    var thirdChoice = CaravanConfinementMouthChoice.COOPERATE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            "[color=brown]In any case, people won't buy a slave based on its name alone.
                            There's more [b]important[/b] parts that need checking.[/color]"
                            You instinctively move your tail in between your legs to cover up your groin.
                            You don't like where this is headed,
                            but at least the fat human seems less [i]sexually inclined[/i] than the wolf.
                            He strikes you as more of a [i]businessman[/i] than the bandit who caught you.
                            With some luck, he might [i]actually[/i] be interested in simply [i]checking[/i] your body for injuries and whatnot,
                            instead of attempting to take advantage of the situation.
                        [/p]
                        [p]
                            Letting go of your collar, the human grabs you by the top of your scaly head.
                            Through brute force, he janks your head backwards, tilting your visage up to face his own.
                            Using his other hand, he forcibly spreads your lips with a pair of thick, unwashed fingers.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Bite</button>`;

        var tooltip = global.parser.parse(`Attempt to bite the human's hand.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Close mouth</button>`;

        var tooltip = global.parser.parse(`Keep your teeth tightly pressed together to seal off the rest of your muzzle.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Cooperate</button>`;

        var tooltip = global.parser.parse(`Open your mouth wide, like a good little [i]pet[/i].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var CaravanConfinementMouthChoice = {
    BITE: 1,
    TEETH: 2,
    COOPERATE: 3
};

// END scenes\Enslavement\CaravanConfinement\mouth\CaravanConfinementMouth.js

// scenes\Enslavement\CaravanConfinement\name\CaravanConfinementGlare.js

/**
 * Name section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementGlare(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementNameChoice.GLARE;
    var reqController = ctrl.name;
    var subController = ctrl.postName;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementMouth(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var begged = !global.kobold.history.shared.enslavement.captureFucked;
        var enjoyed = global.kobold.history.shared.enslavement.captureEnjoyed;
        var toReturn = `[p]
                            You may be his [i]slave[/i], but that doesn't mean you have to do what he says.
                            Well, okay, [i]maybe[/i] it does, but you're still not doing it!
                            What does he need your name for anyway?
                            To [b]engrave[/b] on your [b]collar[/b]?!
                            Screw that!
                            You're not telling him [b]anything[/b].
                            He can go to [b]hell[/b] for all you care!
                        [/p]
                        [p]
                            Your resolve bolstered, you glare up at the chubby human,
                            returning his hateful gaze with equal amounts of disdain.
                            Your muzzle remains tightly sealed, not a single sound escaping your lips.
                            The man is visibly growing annoyed.
                            He voices his anger in the form of a low-pitched growl.
                            You could almost mistake him for the wolf like this, if it weren't for his far less athletic physique.
                            "[color=brown]Don't you know how to talk, you miserable [b]mutt[/b]?![/color]"
                        [/p]
                        [p]
                            "[color=gblue]${male ? `He` : `She`} speaks our language alright.
                            You should have heard'em ${enjoyed ? `begging for more` : `${begged ? `begging for mercy` : `screaming for help`}`} earlier.[/color]"
                            the canine butts in.
                            "[color=brown]So instead of being dumb, the lizard's just being uppity.
                            Good.
                            Disobedience can be fixed.
                            Stupidity, however, can not.
                            If I had my way, I'd [b]beat[/b] some sense into it, but bruised merchandise doesn't sell.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\name\CaravanConfinementGlare.js

// scenes\Enslavement\CaravanConfinement\name\CaravanConfinementGrowl.js

/**
 * Name section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementGrowl(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementNameChoice.GROWL;
    var reqController = ctrl.name;
    var subController = ctrl.postName;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementMouth(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Who does this [b]filthy human[/b] think he is?!
                            Maybe if he lost some weight and showed you some [b]common courtesy[/b],
                            you'd [b]respect[/b] him enough to honor his request.
                            The sheer tone with which he asked for your name alone is enough to make you [b]not[/b] want to comply.
                        [/p]
                        [p]
                            You softly growl at the chubby human,
                            the rumbling noise emanating from the back of your throat growing louder and louder as you reflect on the way he's treated you thus far.
                            In little short of five minutes, he's managed to be [b]far[/b] more obnoxious than the canine who captured you ever was!
                            At least the wolf doesn't [b]insult[/b] and [b]berate[/b] you every chance he gets.
                        [/p]
                        [p]
                            The human notices your display of defiance.
                            He menacingly raises his hand, but manages to restrain himself for the time being,
                            instead venting his frustration at the wolf.
                            "[color=brown]It's growling.
                            Did you bring me a [b]feral[/b] kobold to sell?!
                            Might as well take it to the [b]butcher[/b] straight away![/color]"
                        [/p]
                        [p]
                            "[color=gblue]It's not one of those tribal kobolds.
                            It said something earlier, when I caught it.
                            At least I think it did?"[/color]"
                            The wolf responds, clearly upset, like [b]he[/b]'s the one being blamed for [b]your[/b] actions.
                            He continues his defensive rambling:
                            "[color=gblue]It doesn't [b]look[/b] feral anyway.
                            And why would a tribal lizard steal a bag of coins?
                            They don't even [b]live[/b] this close to Varanar![/color]"
                        [/p]
                        [p]
                            The human lowers his threatening hand, warily exchanging glances with both you and the canine.
                            "[color=brown]I hope for both your sakes the lizard knows how to speak.
                            Disobedience can be fixed, but there isn't a single buyer I can think of that would be interested in a [b]savage[/b] kobold.
                            Unless you want to keep it as a fucktoy, we might be better off just roasting it over the fire.[/color]"
                        [/p]
                        [p]
                            "[color=gblue]I said it knows how to speak.
                            Maybe it doesn't like humans.
                            Plenty of other buyers around, right?[/color]"
                            The wolf chuckles.
                            The human utters an angry harrumph.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\name\CaravanConfinementGrowl.js

// scenes\Enslavement\CaravanConfinement\name\CaravanConfinementState.js

/**
 * Name section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementState(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementNameChoice.STATE;
    var reqController = ctrl.name;
    var subController = ctrl.postName;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementMouth(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.nameStated = true;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Terrified of the well-set man still holding your metal collar,
                            you quickly and meekly stammer out your name.
                            The human's angry grimace visibly mellows out, if just a little.
                            "[color=brown]${name}?
                            That's a lousy name for a slave, let alone a kobold.
                            Who gave it to you?
                            A court jester, a three year old, or a senile dragon?[/color]"
                        [/p]
                        [p]
                            The caravan guard chuckles at his own joke,
                            but his laughter comes to a halt when he realizes neither you nor the wolf found his beratement enjoyable.
                            After a sigh and some mumbling to himself, he continues.
                            "[color=brown]I'd give you a more suitable moniker myself,
                            but that pleasure belongs to whoever ends up buying your sorry ass.
                            At least you know how to speak.
                            That'll up your value some.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\name\CaravanConfinementState.js

// scenes\Enslavement\CaravanConfinement\name\CaravanConfinementName.js

/**
 * Name section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementName(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.arrival;
    var subController = ctrl.name;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new CaravanConfinementGrowl(ctrl);
    var secondNext = new CaravanConfinementGlare(ctrl);
    var thirdNext = new CaravanConfinementState(ctrl);

    var firstChoice = CaravanConfinementNameChoice.GROWL;
    var secondChoice = CaravanConfinementNameChoice.GLARE;
    var thirdChoice = CaravanConfinementNameChoice.STATE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With the two men having reached an accord, the situation quickly diffuses.
                            Done butting heads, their attention drifts to you once more.
                            "[color=gblue]So, what price do you think the lizard'll fetch?[/color]" asks the wolf, whilst licking his lips,
                            though you know not whether it's a [i]lustful[/i] lick, or if he's just eager to hear how much of a [i]bonus[/i] he'll be getting.
                        [/p]
                        [p]
                            "[color=brown]It depends.[/color]"
                            The human speaks.
                            "[color=brown][i]Good[/i] slaves can fetch up to a hundred coins.
                            Far from nothing, right?
                            Bad ones, though.
                            You know, the ones that are worn out, used and abused,
                            the ones you can't even get a rise out of anymore despite [b]still[/b] being disobedient,
                            [b]nobody[/b] wants those.
                            Let's see how much this one is worth, shall we?[/color]"
                        [/p]
                        [p]
                            You [b]really[/b] don't like the thought of being [i]appraised[/i], but you strongly doubt you have a say in the matter.
                            The caravan master turns to face you.
                            Casting down a stern gaze, the man addresses you:
                            "[color=brown]Let's start off simple.
                            Kobold.
                            Your name.[/color]"
                        [/p]
                        [p]
                            Confused, and more than a little intimidated, you hesitate, your brain freezing up completely.
                            You open your muzzle, yet no words escape your mouth.
                            The human, lacking patience for someone who tried to [b]steal[/b] from him, repeats himself:
                            "[color=brown]Your name, [b]lizard[/b]. State. Your. Name.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Growl</button>`;

        var tooltip = global.parser.parse(`Growl at the man. Who does he think he is, ordering you around?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Glare</button>`;

        var tooltip = global.parser.parse(`Angrily and silently stare at him in defiance.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Reply</button>`;

        var tooltip = global.parser.parse(`Comply with the human, and state your name.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 170px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var CaravanConfinementNameChoice = {
    GROWL: 1,
    GLARE: 2,
    STATE: 3
};

// END scenes\Enslavement\CaravanConfinement\name\CaravanConfinementName.js

// scenes\Enslavement\CaravanConfinement\arrival\CaravanConfinementArrival.js

/**
 * Arrival section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementName(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            After a long, humiliating walk, the two of you finally arrive back at the money transport.
                            The sun luckily went down about halfway through the trek, darkness somewhat concealing your
                            nudity${fucked ? ` [sneak]and the cum leaking from your still slightly gaping ${male ? `tailhole` : `cunt`}[/sneak]` : ``}.
                            A small campfire along the side of the road illuminates the area.
                            Combined with a couple of torches affixed to the carts themselves, the convoy is lit well enough to scare off any would-be midnight thieves.
                        [/p]
                        [p]
                            While some caravan guards are busy patrolling and standing watch, most of them are seated around the warming flames.
                            The mood is audibly jolly.
                            You aren't even close to them,
                            but you can already [b]reek[/b] the hefty smell of the copious amounts of poorly brewed alcohol they're gulping down.
                            Amongst the group is the human that was chasing you earlier, sitting next to his dog.
                            He is the first to notice the wolf's triumphant return.
                            After a joyous greeting, all eyes turn to you.
                        [/p]
                        [p]
                            While an entire group of unruly, armed and drunken men of various species staring down your naked form is intimidating, to say the least,
                            the worst of your imminent worries are quelled when a more [i]rational looking[/i] fellow emerges from the front of the convoy.
                            It's the caravan master!
                            The [i]one[/i] human around who [i]doesn't[/i] look like he was ripped straight out of a portrait depicting a band of bandits.
                            And, going by his fancy imperial tunic, he's in charge of this whole operation.
                            Surely, one of the king's sergeants won't stand for a [i]drunken gangrape[/i], right?
                        [/p]
                        [p]
                            "[color=brown]So [b]this[/b] is our little [b]thief[/b]?[/color]" the bulky man speaks,
                            adjusting his belt as though to assert his dominance over the wolf.
                            "[color=gblue]Eyup.[/color]" comes the canine's response.
                            "[color=gblue]Caught'em running through the woods. Would have been halfway to Salamar by now, if not for me and Kajar.[/color]"
                            You assume Kajar is the human that was chasing you earlier.
                        [/p]
                        [p]
                            The caravan master casts a glare your way.
                            The hateful stare sends shivers down your spine.
                            "[color=brown]And what about the money?
                            Did you get it back, or are we having kobold meat for dinner?[/color]"
                            He practically [b]spits[/b] out the world [i]kobold[/i], his voice heavy with disdain.
                        [/p]
                        [p]
                            The canine pats his pocket, rattling the hoard of coins contained within.
                            A smug smile forms on his face.
                            He's holding all of the cards in the palm of his hand, and he knows it.
                            "[color=gblue]Two conditions.[/color]"
                            The human is clearly irked, his head jerking to face the lupine once more.
                            "[color=brown][b]Conditions?![/b]
                            You work for me!
                            Now hand over the bloody coin, or I'll have your entire gang of misfits [b]beheaded[/b]![/color]"
                        [/p]
                        [p]
                            The wolf seems unfazed by the caravan master's threat.
                            Once again, he repeats himself, a little louder.
                            "[color=gblue][b]Two. Conditions.[/b][/color]"
                            Not interrupted by his superior this time around, the canine states his terms.
                            "[color=gblue]Double pay for me and Kajar.
                            On top of that, I get the lizard.[/color]"
                            Grabbing you by the side of your head, the furred bandit tugs your face towards his clothed groin,
                            holding you close to him, flaunting his [i]ownership[/i].
                        [/p]
                        [p]
                            The human takes a moment to consider his options.
                            "[color=brown]Fine, double your [b]measly[/b] pay.[/color]"
                            Reaching for your metal collar, the caravan master firmly [b]yanks[/b] you towards him,
                            tearing you from the lupine's grasp.
                            "[color=brown]But the kobold is [b]mine[/b] by law.
                            It stole from [b]me[/b], not [b]you[/b].[/color]"
                        [/p]
                        [p]
                            The lupine chuckles.
                            "[color=gblue]Law?
                            We may be close, but we're not in Varanar yet.
                            The only [b]law[/b] in these woods is that the guy with the biggest gang gets what he wants.
                            And right now, that guy just happens to be [b]me[/b].[/color]"
                            The wolf bares his teeth.
                            The human grits his.
                            They glare at one another.
                            A small standoff ensues.
                            Tension is tangibly rising.
                        [/p]
                        [p]
                            "[color=brown]Half.[/color]"
                            the caravan master speaks, breaking the unnerving silence.
                            "[color=brown]I get two tries to sell it.
                            Once at the hamlet, once in the city proper.
                            You get half of whatever people are willing to pay for this [b]miserable[/b] excuse of a [b]thief[/b].[/color]"
                            The wolf narrows his eyes.
                            "[color=gblue]And if you can't sell'em?[/color]"
                        [/p]
                        [p]
                            "[color=brown]A kobold that doesn't sell is [b]useless[/b] to me.
                            If nobody wants it, it'll be yours to keep.[/color]"
                            The wolf's turn to ponder his choices.
                            After exchanging angry stares for a few more harrowing seconds, he replies:
                            "[color=gblue]Deal,
                            but if you [b]dare[/b] doublecross us, neither the baron, nor the king himself will be able to save your sorry ass.[/color]"
                            The human snickers.
                            "[color=brown]Unlike you [b]thugs[/b], I am a man of my word.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("forest_night");
        ctrl.bgm.loop();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\CaravanConfinement\arrival\CaravanConfinementArrival.js

// scenes\Enslavement\CaravanConfinement\CaravanConfinementController.js

/**
 * Controller for the Caravan Confinement scene.
 * @param {string} sceneId The id of the scene.
 */
function CaravanConfinementController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = true;
    this.nextSceneName = "SlaveNoonTwo";
    this.nextFolderName = "Enslavement/DayTwo";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");

    this.name = new ChoiceController(id, "name");

    this.postName = new ChangeController(id, "postName", function () {
        var choice = that.name.get();
        if (choice === CaravanConfinementNameChoice.GROWL) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 1;
            global.kobold.status.mental.decrease(3, "Threatened and insulted");
        } else if (choice === CaravanConfinementNameChoice.GLARE) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 2;
            global.kobold.status.mental.decrease(2, "Getting yelled at");
        } else {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 3;
            global.kobold.status.mental.decrease(1, "Crude joke");
        }
    }, function () {
        var choice = that.name.get();
        if (choice === CaravanConfinementNameChoice.GROWL) {
            return global.ui.change.buildNotification([
                new Change("Called a feral", "Sanity", -1),
                new Change("Threatened slap", "Sanity", -2)
            ]);
        } else if (choice === CaravanConfinementNameChoice.GLARE) {
            return global.ui.change.buildNotification([
                new Change("Yelled at", "Sanity", -2)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Crude joke", "Sanity", -1)
            ]);
        }
    });

    this.mouth = new ChoiceController(id, "mouth");

    this.postMouth = new ChangeController(id, "postMouth", function () {
        var choice = that.mouth.get();
        if (choice === CaravanConfinementMouthChoice.BITE) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 1;
            global.kobold.status.physical.decrease(8, "Minor abuse");
            global.kobold.status.mental.decrease(6, "Threatened and examined");
        } else if (choice === CaravanConfinementMouthChoice.TEETH) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 2;
            global.kobold.status.mental.decrease(6, "Threatened and graded");
        } else {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 3;
            global.kobold.status.mental.decrease(3, "Examined and graded");
        }
    }, function () {
        var choice = that.name.get();
        if (choice === CaravanConfinementMouthChoice.BITE) {
            return global.ui.change.buildNotification([
                new Change("Slapped", "Health", -3),
                new Change("Choked", "Health", -5),
                new Change("Threatened", "Sanity", -5),
                new Change("Examined", "Sanity", -1)
            ]);
        } else if (choice === CaravanConfinementMouthChoice.TEETH) {
            return global.ui.change.buildNotification([
                new Change("Threatened", "Sanity", -3),
                new Change("Examined", "Sanity", -1),
                new Change("Graded", "Sanity", -2)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Examined", "Sanity", -1),
                new Change("Graded", "Sanity", -2)
            ]);
        }
    });

    this.tight = new ChoiceController(id, "tight");

    this.postTight = new ChangeController(id, "postTight", function () {
        var choice = that.tight.get();
        if (choice === CaravanConfinementTightnessChoice.CLAW) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 1;
            global.kobold.status.mental.decrease(8, "Unwillingly touched");
            global.kobold.status.exertion.increase(5, "Loins probed");
        } else if (choice === CaravanConfinementTightnessChoice.STILL) {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 2;
            global.kobold.status.mental.decrease(8, "Reluctantly touched");
            global.kobold.status.exertion.increase(5, "Loins probed");
        } else {
            global.kobold.history.shared.enslavement.nightOne.complianceRating += 3;
            global.kobold.status.exertion.increase(5, "Loins probed");
        }
    }, function () {
        var choice = that.tight.get();
        if (choice === CaravanConfinementTightnessChoice.CLAW) {
            return global.ui.change.buildNotification([
                new Change("Unwillingly touched", "Sanity", -5),
                new Change("Meekness exposed", "Sanity", -3),
                new Change("Loins probed", "Sexual exhaustion", +5, true)
            ]);
        } else if (choice === CaravanConfinementTightnessChoice.STILL) {
            return global.ui.change.buildNotification([
                new Change("Unwillingly touched", "Sanity", -5),
                new Change("Loins probed", "Sexual exhaustion", +5, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Loins probed", "Sexual exhaustion", +5, true)
            ]);
        }
    });

    this.cart = new ChoiceController(id, "cart");

    this.bang = new ChangeController(id, "bang", function () {
        global.kobold.status.physical.decrease(23, "Bashed head against floor");
        global.kobold.status.mental.decrease(12, "Immense pain");
        global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
        global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hurt self", "Health", -18),
            new Change("Passed out", "Health", -5),
            new Change("Pain without gain", "Sanity", -12),
            new Change("Endured pain", "Endurance", +1),
            new Change("Did something stupid", "Intelligence", -1)
        ]);
    });

    this.count = new ChangeController(id, "count", function () {
        global.kobold.status.mental.increase(7, "Fell asleep");
        global.kobold.stats.increaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Keeping busy", "Sanity", +2),
            new Change("Dozed off", "Sanity", +5),
            new Change("Practiced counting", "Intelligence", +1)
        ]);
    });

    this.gaze = new ChangeController(id, "gaze", function () {
        global.kobold.status.mental.increase(8, "Fell asleep");
        global.kobold.stats.increaseStat(StatsEnum.LUCK, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Tranquility", "Sanity", +3),
            new Change("Dozed off", "Sanity", +5),
            new Change("Star-blessed", "Luck", +1)
        ]);
    });

    this.talk = new ChangeController(id, "talk", function () {
        global.kobold.status.mental.increase(10, "Onesided conversation");
        global.kobold.stats.increaseStat(StatsEnum.CHARISMA, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Onesided conversation", "Sanity", +10),
            new Change("Practiced talking to people", "Charisma", +1)
        ]);
    });

    this.breakFail = new ChangeController(id, "breakFail", function () {
        global.kobold.status.stamina.decrease(5, "Struggling");
        global.kobold.stats.increaseStat(StatsEnum.STRENGTH, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Struggling", "Stamina", -5),
            new Change("Workout", "Strength", +1)
        ]);
    });

    this.breakSucceed = new ChangeController(id, "breakSucceed", function () {
        global.kobold.history.shared.enslavement.nightOne.complianceRating -= 2;
        global.kobold.status.physical.decrease(5, "Rope burn");
        global.kobold.status.stamina.decrease(5, "Struggling");
        global.kobold.status.mental.increase(10, "Newfound freedom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Rope burn", "Health", -5),
            new Change("Struggling", "Stamina", -5),
            new Change("Hope", "Sanity", +5),
            new Change("Freedom", "Sanity", +5)
        ]);
    });

    this.breakSucceedContinue = new ChangeController(id, "breakSucceedContinue", function () {
        global.kobold.status.physical.decrease(20, "Head bashed");
        global.kobold.status.mental.decrease(15, "Hope shattered");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Head bashed", "Health", -15),
            new Change("Knocked out", "Health", -5),
            new Change("Hope shattered", "Sanity", -15)
        ]);
    });

    this.slipFail = new ChangeController(id, "breakFail", function () {
        global.kobold.status.stamina.decrease(5, "Struggling");
        global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Struggling", "Stamina", -5),
            new Change("Workout", "Agility", +1)
        ]);
    });

    this.slipSucceed = new ChangeController(id, "breakSucceed", function () {
        global.kobold.history.shared.enslavement.nightOne.complianceRating -= 2;
        global.kobold.status.physical.decrease(5, "Rope burn");
        global.kobold.status.stamina.decrease(5, "Struggling");
        global.kobold.status.mental.increase(10, "Newfound freedom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Rope burn", "Health", -5),
            new Change("Struggling", "Stamina", -5),
            new Change("Hope", "Sanity", +5),
            new Change("Freedom", "Sanity", +5)
        ]);
    });

    this.slipSucceedContinue = new ChangeController(id, "slipSucceedContinue", function () {
        global.kobold.status.physical.decrease(20, "Head bashed");
        global.kobold.status.mental.decrease(15, "Hope shattered");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Head bashed", "Health", -15),
            new Change("Knocked out", "Health", -5),
            new Change("Hope shattered", "Sanity", -15)
        ]);
    });

    this.preContinue = new ContinueController(id, "preContinue");

    this.bgm = new AudioController(id, "res/audio/enslavement/camp.mp3", 100);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

// END scenes\Enslavement\CaravanConfinement\CaravanConfinementController.js

// scenes\Enslavement\CaravanConfinement\CaravanConfinement.js

/**
 * First night in enslavement.
 */
function CaravanConfinement() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "CaravanConfinement";
    var sceneName = "Enslavement, Night One";
    var sceneSubfolder = "Enslavement";
    var ctrl = new CaravanConfinementController(sceneId);
    var arrival = new CaravanConfinementArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]Enslavement[/t]`);
        tab += global.parser.parse(`[st]Night one[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new CaravanConfinement();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Enslavement\CaravanConfinement\CaravanConfinement.js



// END SCENE CaravanConfinement

