

// SCENE ForestRiver

// scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstreamSuccess.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepUpstreamSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.upstreamSuccess;

    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = ctrl.homeSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverEvaded = true;
        var toReturn = `[p]
                            They'll be expecting you to go downstream.
                            It's the easy route.
                            The path of least resistance.
                            What they [b]won't[/b] expect, is for you to fight [b]against[/b] the current.
                            They'll never see it coming.
                            You'll take them by surprise,
                            and you'll be gone long before they realize where you went.
                            Ignoring the human's order for you to stop, you take hold of the rock you were passing by,
                            and [b]pull[/b] yourself behind it, out of view.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Playing hide and seek?! I'm coming to get you, lizard![/color]"
                            [/big]
                        [/p]
                        [p]
                            The big brute's bass shouting is loud enough to scare several birds from their nests,
                            an entire [b]flock[/b] dramatically bursting from the treeline-canopy.
                            He ups his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            His walking is slow enough for you to quickly devise a plan.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            That's it!
                            Your tiny size may be your salvation here.
                            You can [b]dive[/b] underneath the water, and make your way back towards the shore unseen!
                            If you can hold your breath for long enough,
                            you [i]should[/i] be able to reach the shore and make your getaway before they figure out where you went.
                            With the strong man rapidly approaching, you don't have much time to think things through.
                            You need to go.
                            You need to go [b]now[/b].
                        [/p]
                        [p]
                            Filling your frigid lungs with as much air as they can hold, you plunge your head underneath the water,
                            dive to the bottom of the river, and begin to make your way towards the shore from which you came,
                            aiming for a small alcove a bit further upstream, so you can circumvent the group of thugs.
                            While still hampering your progress, the current is quite a bit weaker at the riverbed than it was at the surface of the water.
                            By digging your claws into the mud, and clambering along the myriad of submerged rocks,
                            you manage to move quite a bit faster than you could while swimming.
                            You're slowly running out of air, but if you can keep up this pace, you might just make it out of here alive!
                        [/p]
                        [p]
                            [big]
                                "[color=green]It's gone!
                                Where the hell did that little cretin go?!
                                Look around, guys!
                                Can't be far![/color]"
                            [/big]
                        [/p]
                        [p]
                            Your disappearance being noted is the least of your concerns.
                            You're getting close to the shore, but as you pass by the pillars of the wooden bridge,
                            your drained lungs begin to [b]burn[/b], [b]begging[/b] you to come up for air.
                            Through sheer willpower and endurance alone, you keep clambering forwards along the bottom of the river,
                            your consciousness slowly waning as you get to ever-more shallow waters.
                            You black out for a minute, your mind lacking the oxygen needed to stay fully awake.
                        [/p]
                        ${global.ui.condSucc(`Endurance above 5`)}
                        [p]
                            When you come to, you find yourself lying on the riverbank.
                            You must have subconsciously pulled yourself ashore.
                            The burly man is still in the river looking for you, his comrades scouring the water's surface for any signs of their prey.
                            You want to take a moment to catch your breath,
                            but every second counts.
                            You scramble to your aching legs,
                            and wearily stumble back into the forest proper.
                        [/p]
                        [p]
                            You catch your breath without stopping, your stumbling gait turning into a proper walk,
                            and then an outright [b]jog[/b] as you hurry to get away from the thuggish trio.
                            They don't seem to be following you, probably still looking for you in the river.
                            Your ambition to get to Varanar before the end of the day completely [b]ruined[/b],
                            you head for your home in the woods,
                            hoping to be spared any further unpleasant encounters.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstreamSuccess.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstreamFail.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepUpstreamFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.upstreamFail;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        var toReturn = `[p]
                            They'll be expecting you to go downstream.
                            It's the easy route.
                            The path of least resistance.
                            What they [b]won't[/b] expect, is for you to fight [b]against[/b] the current.
                            They'll never see it coming.
                            You'll take them by surprise,
                            and you'll be gone long before they realize where you went.
                            Ignoring the human's order for you to stop, you take hold of the rock you were passing by,
                            and [b]pull[/b] yourself behind it, out of view.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Playing hide and seek?! I'm coming to get you, lizard![/color]"
                            [/big]
                        [/p]
                        [p]
                            The big brute's bass shouting is loud enough to scare several birds from their nests,
                            an entire [b]flock[/b] dramatically bursting from the treeline-canopy.
                            He ups his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            His walking is slow enough for you to quickly devise a plan.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            That's it!
                            Your tiny size may be your salvation here.
                            You can [b]dive[/b] underneath the water, and make your way back towards the shore unseen!
                            If you can hold your breath for long enough,
                            you [i]should[/i] be able to reach the shore and make your getaway before they figure out where you went.
                            With the strong man rapidly approaching, you don't have much time to think things through.
                            You need to go.
                            You need to go [b]now[/b].
                        [/p]
                        [p]
                            Filling your frigid lungs with as much air as they can hold, you plunge your head underneath the water,
                            dive to the bottom of the river, and begin to make your way towards the shore from which you came,
                            aiming for a small alcove a bit further upstream, so you can circumvent the group of thugs.
                            While still hampering your progress, the current is quite a bit weaker at the riverbed than it was at the surface of the water.
                            By digging your claws into the mud, and clambering along the myriad of submerged rocks,
                            you manage to move quite a bit faster than you could while swimming.
                            You're slowly running out of air, but if you can keep up this pace, you might just make it out of here alive!
                        [/p]
                        [p]
                            [big]
                                "[color=green]It's gone!
                                Where the hell did that little cretin go?!
                                Look around, guys!
                                Can't be far![/color]"
                            [/big]
                        [/p]
                        [p]
                            Your disappearance being noted is the least of your concerns.
                            You're getting close to the shore, but as you pass by the pillars of the wooden bridge,
                            your drained lungs begin to [b]burn[/b], [b]begging[/b] you to come up for air.
                            Through sheer willpower and endurance alone, you keep clambering forwards along the bottom of the river,
                            your consciousness slowly waning as you get to ever-more shallow waters.
                            You black out for a minute, your mind lacking the oxygen needed to stay fully awake.
                        [/p]
                        ${global.ui.condFail(`Endurance below 6`)}
                        [p]
                            When you come to, you find yourself clinging to one of the pillars of the bridge.
                            You must have subconsciously pulled yourself upwards to stave off death by drowning.
                            Your entire body aches.
                            You feel extremely lightheaded.
                            You barely have enough energy left in you to keep yourself afloat.
                            And to make matters worse, the burly man pursuing you finally figures out where you went.
                        [/p]
                        [p]
                            [big]
                                "[color=green]There it is! Shoot it![/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the edged rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile only [b]barely[/b] misses your head,
                            crashing against and outright [b]splintering[/b] the pillar you were clambering to.
                        [/p]
                        [p]
                            The slinger, too, hurls his load, releasing his more bluntly shaped piece of stone, hurling it towards you with surprising skill.
                            Unlike his comrade, he [i]doesn't[/i] miss.
                            The rock impacts heavily against your cranium.
                            You hear a loud [b]crack[/b], and it doesn't take a sharp mind to realize that it wasn't the stone that broke.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your worn out body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstreamFail.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstream.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepUpstream(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverKeepChoice.UP;
    var reqController = ctrl.keepGoing;

    var toFail = new ForestRiverKeepUpstreamFail(ctrl);
    var toSuccess = new ForestRiverKeepUpstreamSuccess(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.endurance() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\upstream\ForestRiverKeepUpstream.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstreamSuccess.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepDownstreamSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.downstreamSuccess;
    
    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = ctrl.homeSceneName;
    
    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverEvaded = true;
        var toReturn = `[p]
                            Heading straight would be too predictable.
                            The two guys on the shore could easily hit you if you swim in a straight line.
                            Upstream, you'd be even [b]slower[/b].
                            A sitting duck.
                            That leaves only one way to go.
                            The sensible route.
                            The path of least resistance.
                            You need to head downstream.
                            Ignoring the human's order for you to stop, you suddenly take a hard left,
                            and instantly up your pace, swimming as fast as you can along with the current of the stream.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hey! Did you hear me?![/color]"
                            [/big]
                        [/p]
                        [p]
                            You enter a small river-rapid.
                            The water's flow grips your featherweight body, pulling you along,
                            propelling you to [b]far[/b] greater speeds than you'd have been able to attain otherwise.
                            You feel like a [b]fish[/b], a [b]master[/b] of swimming, not to mention an [b]escape artist[/b] of the highest quality!
                            If you'd known the river could drive you onwards with such ease,
                            you would have used the current to escape a bunch of previous heists!
                        [/p]
                        [p]
                            [big]
                                "[color=green]The lizard's not listening. [b]Shoot it![/b][/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the sharp rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile misses you by a wide margin,
                            your tiny frame [b]way[/b] too speedy for him to accurately fire at you.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Where did you learn how to aim?! Get it![/color]"
                            [/big]
                        [/p]
                        [p]
                            [big]
                                "[color=cyan]It's going too fast, damnit![/color]"
                            [/big]
                        [/p]
                        [p]
                            And they say [b]kobolds[/b] are incapable of working together.
                            As the two thugs bicker amongst eachother,
                            the slinger that hasn't yet hurled his load releases his more bluntly shaped piece of stone, hurling it towards your head.
                            Due to your current-driven acceleration, you've travelled [b]much[/b] too far for the projectile to even [b]reach[/b] you.
                            It harmlessly plunges into the water, quite a bit away.
                            Looks like you're in the clear!
                            Your plan worked perfectly!
                        [/p]
                        [p]
                            Then, turning your attention back to what's in front of you,
                            you suddenly remember why you [i]hadn't[/i] considered using the river to escape pursuers before.
                            Boulders.
                            Rocks.
                            [b]Sharp[/b] rocks.
                            A lot of them.
                            Directly in your path.
                            You're going too fast to avoid them completely!
                            You'll have to pull out some slick maneuvers if you want to make it out of this in one piece!
                        [/p]
                        ${global.ui.condSucc(`Agility above 5`)}
                        [p]
                            Contorting your body, you narrowly manage to avoid the first rock in your way.
                            While rapidly flailing your arms about, trying to fight the current and slow yourself down,
                            you dodge boulder after boulder, each one coming closer to hitting you than the last.
                            An oddly-shaped rock nearly pokes your eye out, but you manage to yank your head to the side just in time to avoid it.
                            Finally, after a frightening, life-threatening minute full of hazard and split-second decisions,
                            the rocky field clears out, and the river slows down once more.
                            You've survived.
                            For now.
                        [/p]
                        [p]
                            Thoroughly harrowed to the point of being traumatized, you slowly swim back over to the shore you came from.
                            It's too late to go to Varanar, and after barely surviving an adrenaline-fueled, high-stakes dodge-fest,
                            you'd much rather go back to your place to get some rest than scurry around the streets of a metropolis looking for a place to sleep.
                            You crawl ashore, and take a moment to catch your breath.
                            Escaping via the river -- [b]never again[/b].
                        [/p]
                        [p]
                            After calming down for a minute, you rise to your shaky feet,
                            and wearily stumble back into the forest proper.
                            Making sure to circumvent the group of thugs,
                            you begin to make your way back home.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstreamSuccess.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstreamFail.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepDownstreamFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.downstreamFail;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        var toReturn = `[p]
                            Heading straight would be too predictable.
                            The two guys on the shore could easily hit you if you swim in a straight line.
                            Upstream, you'd be even [b]slower[/b].
                            A sitting duck.
                            That leaves only one way to go.
                            The sensible route.
                            The path of least resistance.
                            You need to head downstream.
                            Ignoring the human's order for you to stop, you suddenly take a hard left,
                            and instantly up your pace, swimming as fast as you can along with the current of the stream.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hey! Did you hear me?![/color]"
                            [/big]
                        [/p]
                        [p]
                            You enter a small river-rapid.
                            The water's flow grips your featherweight body, pulling you along,
                            propelling you to [b]far[/b] greater speeds than you'd have been able to attain otherwise.
                            You feel like a [b]fish[/b], a [b]master[/b] of swimming, not to mention an [b]escape artist[/b] of the highest quality!
                            If you'd known the river could drive you onwards with such ease,
                            you would have used the current to escape a bunch of previous heists!
                        [/p]
                        [p]
                            [big]
                                "[color=green]The lizard's not listening. [b]Shoot it![/b][/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the sharp rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile misses you by a wide margin,
                            your tiny frame [b]way[/b] too speedy for him to accurately fire at you.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Where did you learn how to aim?! Get it![/color]"
                            [/big]
                        [/p]
                        [p]
                            [big]
                                "[color=cyan]It's going too fast, damnit![/color]"
                            [/big]
                        [/p]
                        [p]
                            And they say [b]kobolds[/b] are incapable of working together.
                            As the two thugs bicker amongst eachother,
                            the slinger that hasn't yet hurled his load releases his more bluntly shaped piece of stone, hurling it towards your head.
                            Due to your current-driven acceleration, you've travelled [b]much[/b] too far for the projectile to even [b]reach[/b] you.
                            It harmlessly plunges into the water, quite a bit away.
                            Looks like you're in the clear!
                            Your plan worked perfectly!
                        [/p]
                        [p]
                            Then, turning your attention back to what's in front of you,
                            you suddenly remember why you [i]hadn't[/i] considered using the river to escape pursuers before.
                            Boulders.
                            Rocks.
                            [b]Sharp[/b] rocks.
                            A lot of them.
                            Directly in your path.
                            You're going too fast to avoid them completely!
                            You'll have to pull out some slick maneuvers if you want to make it out of this in one piece!
                        [/p]
                        ${global.ui.condFail(`Agility below 6`)}
                        [p]
                            Contorting your body, you narrowly manage to avoid the first rock in your way.
                            While rapidly flailing your arms about, trying to fight the current and slow yourself down,
                            you dodge boulder after boulder, each one coming closer to hitting you than the last.
                            An oddly-shaped rock nearly pokes your eye out, but you manage to yank your head to the side just in time to avoid it.
                            For almost an entire minute, you dodge various boulders and outcroppings,
                            until there finally comes one you [b]fail[/b] to avoid.
                        [/p]
                        [p]
                            Your head heavily impacts against the rock.
                            You hear a loud [b]crack[/b], and it doesn't take a sharp mind to realize that it wasn't the stone that broke.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your worn out body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstreamFail.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstream.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepDownstream(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverKeepChoice.DOWN;
    var reqController = ctrl.keepGoing;

    var toFail = new ForestRiverKeepDownstreamFail(ctrl);
    var toSuccess = new ForestRiverKeepDownstreamSuccess(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.agility() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\downstream\ForestRiverKeepDownstream.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\ForestRiverKeepOther.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepOther(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverKeepChoice.OTHER;
    var reqController = ctrl.keepGoing;
    var changeController = ctrl.otherSide;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        var toReturn = `[p]
                            You need to conserve momentum, and keep going the way you were going!
                            The buff dude isn't going to be able to catch up, and you doubt his [i]friends[/i] are very skilled at using their weapons.
                            Ignoring the human's order for you to stop, you keep swimming forwards,
                            upping the pace to as fast as your frigid limbs can carry you,
                            changing from a doggy paddling to a full-on breaststroke technique.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hey! Did you hear me?![/color]"
                            [/big]
                        [/p]
                        [p]
                            The big brute's bass scream is loud enough to scare several birds from their nests,
                            an entire [b]flock[/b] dramatically bursting from the treeline-canopy.
                            He ups his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            His walking is nowhere near fast enough to keep up with you.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            [big]
                                "[color=green]What are you waiting for?! Shoot'em![/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the sharp rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile only [b]barely[/b] misses the semi-submerged leader's head,
                            whirring right by him, [b]plunging[/b] into the water directly in front of you.
                            Two near-hits, but it'll take more than a small splash getting water in your eyes to stop you.
                            Sheer adrenaline suppresses the immense fear that the bandits are more skilled than you'd have imagined.
                        [/p]
                        [p]
                            [big]
                                "[color=green]You almost hit [b]me[/b], you stupid idiot![/color]"
                            [/big]
                        [/p]
                        [p]
                            [big]
                                "[color=cyan]Do you want me to shoot the kobold or not?! Get out of the way![/color]"
                            [/big]
                        [/p]
                        [p]
                            And they say [b]kobolds[/b] are incapable of working together.
                            As the thugs bicker amongst eachother, you begin to near the riverbank, your salvation close at hand.
                            The slinger that hasn't yet hurled his load, releases his more bluntly shaped piece of stone, hurling it towards your head.
                            Like the other human before him, he missed you but [b]narrowly[/b],
                            his rock impacting against and bouncing off of a boulder sticking out from the river,
                            mere inches away from your face.
                            Driven by panic, you push your hypothermic body to its very limits,
                            squeezing every ounce of power from your frostbitten limbs to carry you forwards as quickly as you posssibly can go.
                        [/p]
                        [p]
                            Before the bandits gunning for you manage to load their second shots, and while the burly man isn't even [b]halfway[/b] across yet,
                            you finally reach the river's other shore.
                            Completely exhausted, you clamber out onto the riverbank, practically [b]collapsing[/b] into the shallow water.
                            But you're not done yet.
                            You're at the end of your rope, but if you stop now, this'll all have been for nothing.
                            You raise yourself to your hands and feet once more.
                            Lifting your head, you spot another group of humans directly in front of you, walking right at you.
                        [/p]
                        [p]
                            Like the clothes of the gang chasing you are dyed yellow,
                            this lot's more fancy attire is a bright purple.
                            A bowman, a crossbowman and a strongman with a large, two-handed sword.
                            The fellow with the bow has a fine moustache.
                            He's puffing smoke from a robust ${global.kobold.inventory.createItemWithTooltip(new SmokingPipe())}.
                            A gentleman down on his luck?
                        [/p]
                        [p]
                            For a moment, you fear these are two [b]very similar[/b] groups of the same gang,
                            but the sword-wielding goon soon debunks your suspicions.
                            "[color=purple]What the hell are you [b]copycats[/b] doing crossing the river?![/color]"
                            Two rival parties?
                            "[color=purple]Sending your [b]kobold spies[/b] over to [b]mimic[/b] us better?![/color]"
                        [/p]
                        [p]
                            Before you can explain that you're not with them, and before they can explain that they're not with you,
                            the crossbowman runs up to you, and harshly [b]kicks[/b] you in the side of the head,
                            the crushing impact of his heavy, leather boot sending you [b]flying[/b] backwards into the river.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your weary body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\keep\ForestRiverKeepOther.js

// scenes\ForestToVaranar\ForestRiver\swim\keep\ForestRiverKeep.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeep(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimmingChoice.KEEP;
    var reqController = ctrl.swimming;
    var subController = ctrl.keepGoing;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new ForestRiverKeepOther(ctrl);
    var secondNext =  new ForestRiverKeepUpstream(ctrl);
    var thirdNext =  new ForestRiverKeepDownstream(ctrl);

    var firstChoice = ForestRiverKeepChoice.OTHER;
    var secondChoice = ForestRiverKeepChoice.UP;
    var thirdChoice = ForestRiverKeepChoice.DOWN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You're [b]not[/b] letting yourself fall into the hands of this [b]brute[/b]!
                            Knowing these lowlifes, he might take your money [b]and[/b] your virginity.
                            You can't let that happen.
                            Those rock-based weapons, while undoubtebly lethal, don't look very [i]accurate[/i].
                            You don't think they'll be able to hit you, but then again, you don't know how [i]skilled[/i] the men are.
                            The buff bandit doesn't look like much of a swimmer.
                            You doubt he'll give chase if you manage to put some distance between the two of you.
                        [/p]
                        [p]
                            All you need to do is get [b]out[/b] of the water, so you can flee into the forest, or towards the hamlet.
                            If you go upstream, you can try to hide behind the rock that protects you from the current, and then figure out what you'll do from there.
                            Downstream, the water's pull might be able to give you the extra [i]speed[/i] that you need to escape the men.
                            As a small, lightweight kobold, the current'll accelerate you far more than it will the hulking brute chasing you.
                            With some luck, it'll make you fast enough to avoid the rocks that'll be hurled at you.
                        [/p]
                        [p]
                            Alternatively, you could keep heading straight ahead, towards the other side of the river.
                            If you can reach dry land without getting hit or grabbed, then you should be able to get to the hamlet before they catch up to you.
                            It's a pretty [i]predictable[i] path, but at the same time, you'll be putting some extra distance between the rock-hurlers and yourself.
                            And that may be all that's needed for them to [b]miss[/b].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Other side</button>`;

        var tooltip = global.parser.parse(`Keep going straight ahead!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 185px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Upstream</button>`;

        var tooltip = global.parser.parse(`Fight the current and head for the bridge.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Downstream</button>`;

        var tooltip = global.parser.parse(`Go with the flow to pick up extra speed.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var ForestRiverKeepChoice = {
    OTHER: 1,
    UP: 2,
    DOWN: 3
};

// END scenes\ForestToVaranar\ForestRiver\swim\keep\ForestRiverKeep.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverWeapon.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverWeapon(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverFreezeChoice.WEAPON;
    var reqController = ctrl.freeze;
    var subController = ctrl.weapon;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverReconsider(ctrl);
    var secondNext = new ForestRiverStrike(ctrl);

    var firstChoice = ForestRiverWeaponChoice.RECONSIDER;
    var secondChoice = ForestRiverWeaponChoice.STRIKE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var weaponTT = global.kobold.inventory.createItemTooltip(weapon);
        var rockTT = global.kobold.inventory.createItemTooltip(new Rock());
        var toReturn = `[p]
                            Raise your hands?
                            Fuck no.
                            You're not surrendering to some [b]oaf[/b] just because he has a pair of friends and more muscle-mass than your entire body weight.
                            He may be strong, but you doubt he can take a hit to the top of his head.
                            In fact, out here in the water, you'd say the playing field is pretty [i]even[/i].
                            Out on dry land, you'd have to jump up high to be able to even [b]reach[/b] his head.
                            But in the water, he isn't that much taller than you.
                        [/p]
                        [p]
                            Powerful as he may be, you intend to knock the man out [b]before[/b] he manages to bring his impressive muscles to bear.
                            ${weapon ? `Underneath the surface of the water, you brandish your ${weaponTT}.
                            ` : `For a moment, you pretend to drown, letting yourself sink to the bottom of the river,
                            so you can pick up a ${rockTT} to use as a temporary weapon.
                            "[color=green]I almost thought you were trying to make a run for it.[/color]"
                            the burly man comments, as you surface once more.`}
                            As ${weapon ? `the human` : `he`} approaches, however, doubt begins to cloud your mind.
                            He's [b]really[/b] big.
                            What if this [i]doesn't[/i] work?
                            How will his friends react?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Reconsider</button>`;

        var tooltip = global.parser.parse(`This guy's a bit too [i]buff[/i] to pick a fight with.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Strike</button>`;

        var tooltip = global.parser.parse(`Surprise is your greatest weapon. One swift blow is all you need.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverWeaponChoice = {
    RECONSIDER: 1,
    STRIKE: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverWeapon.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverStrike.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverStrike(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverWeaponChoice.STRIKE;
    var reqController = ctrl.weapon;
    var changeController = ctrl.strike;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        global.kobold.history.shared.forestToVaranar.riverGoliathKilled = true;
        var toReturn = `[p]
                            The man comes to a halt directly in front of you.
                            Now's your chance.
                            Gathering all of your courage and gritting your teeth,
                            you raise your weapon up out of the water, brandishing it up high above.
                            The dim-witted brute dumbfoundedly stares at it,
                            then, before he can react, you [b]plummet[/b] your blunt armament down atop his head,
                            [b]bashing[/b] the muscular man's cranium, caving his skull in.
                        [/p]
                        [p]
                            A loud, satisfying and slightly [i]sickening[/i] [b]crack[/b] raises your hopes high.
                            The human blankly stares at you.
                            His mouth falls agape, as though he's trying to speak, but no words leave his lips.
                            A trickle of blood oozes from his right nostril.
                            His eyes cross, before rolling into the back of his head.
                            Then, finally, after a few tense seconds, the human falls backwards into the water,
                            which freely floods into his open maw.
                            Sinking deeper and deeper,
                            a few final bubbles of air escaping from his lungs is the last you ever see of the big and burly thug.
                        [/p]
                        [p]
                            Pride swells your chest, felling a human that big being no easy feat for a small kobold like yourself.
                            The two men accompanying the beastly human don't know how to react.
                            They look at eachother in disbelief.
                            While their leader sinks to the riverbed,
                            they slowly come to their senses.
                        [/p]
                        [p]
                            [big]
                                "[color=cyan][b]Goliath[/b]! I'll get you for that, you [b]stupid kobold[/b]![/color]"
                            [/big]
                        [/p]
                        [p]
                            The slingshot-wielder aims his weapon, and fires a precise shot your way.
                            Not precise enough, however.
                            The sharp rock flies right by your cheek, missing you by less than an inch!
                            Feeling like you're on top of the world, you aren't the least bit scared.
                            You just took out a [b]monster[/b] of a human.
                            You're not scared of his two lackeys.
                            They can't aim for shit!
                        [/p]
                        [p]
                            You taunt the rock-toting skirmishers, telling them to get in the water so you can knock'em out like you did their leader.
                            One of the two men hasn't blown his load yet, however.
                            Instead of lamenting his boss' death, or getting emotional and firing without proper aim,
                            the slinger takes his time, clearing his head and focusing his [b]hatred[/b].
                            His mind zeroed in on you, he lets loose his more blunt stone, which flies towards you with a gentle arc.
                            Too busy laughing at them, you don't even [b]notice[/b] the heavy projectile until it's too late.
                        [/p]
                        [p]
                            The rock impacts heavily against your cranium.
                            You hear a loud [b]crack[/b], and it doesn't take a sharp mind to realize that it wasn't the stone that broke.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your worn out body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverStrike.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverReconsider.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverReconsider(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverWeaponChoice.RECONSIDER;
    var reqController = ctrl.weapon;
    var changeController = ctrl.reconsider;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        global.kobold.history.shared.forestToVaranar.riverMoneyTaken = true;
        var weapon = ctrl.misc.weapon();
        var weaponTT = global.kobold.inventory.createItemTooltip(weapon);
        var rockTT = global.kobold.inventory.createItemTooltip(new Rock());
        var toReturn = `[p]
                            The man comes to a halt directly in front of you.
                            Now would be your chance to strike, but instead, you [b]completely[/b] freeze up.
                            You swallow in fear, the bandit simply [b]too[/b] imposing for you to act.
                            How the hell does [b]anyone[/b] grow to be that [b]huge[/b]?!
                            Was his father a [b]giant[/b] or something?!
                        [/p]
                        [p]
                            With a lecherous look on his face, the human eyes you up and down.
                            Suddenly, his visage turns to [b]anger[/b].
                            He reaches underwater, and [b]grabs[/b] your ${weapon ? weaponTT : rockTT}-clutching hand by the wrist,
                            squeezing down hard enough to make you drop your weapon!
                            "[color=green]Trying to [b]ambush[/b] me, were you?[/color]"
                            he speaks, leaning down slightly, staring straight into your eyes.
                        [/p]
                        [p]
                            You [b]swear[/b] that you weren't planning to hurt him!
                            Okay, maybe the thought crossed your mind, but you weren't going to go through with it!
                            Honestly!
                            The human completely disregards your excuses.
                            "[color=green]I [i]was[/i] just going to fuck you, but now, I think I'll be taking [b]this[/b].[/color]"
                            With his free hand, he [b]grabs[/b] your coinpouch, and effortlessly [b]tears[/b] it from your neck.
                        [/p]
                        [p]
                            No!
                            You need that!
                            He can't have it!
                            You reach for the purse, but the man teasingly pulls it backwards, treating you like a [b]child[/b].
                            Unable to control yourself, you [b]lash[/b] out in pure rage, [b]scratching[/b] his face with your sharp claws.
                            Snapping back to your senses, a wave of fright washes over you as you realize what you did.
                            The human angrily glares at you, a tiny bit of blood seeping from his cheek.
                        [/p]
                        [p]
                            Oh no!
                            Oh no, no, no!
                            Y-you didn't mean to do that!
                            You got so angry, you lost control for a bit!
                            He can have the coins!
                            As an apology, okay?
                            Y-you're cool, right?
                            Two words are all that leave the bandit's mouth.
                            "[color=green]Good night.[/color]"
                            And with that, be [b]bashes[/b] your forehead with his fist,
                            using every overdeveloped muscle in his inflated arm to [b]knock you out[/b] in a single blow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\weapon\ForestRiverReconsider.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexPlay.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSexPlay(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverMouthDoNotChoice.PLAY;
    var reqController = ctrl.mouthDoNot;
    var changeController = ctrl.sexPlay;

    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = ctrl.homeSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The man fucks you underwater, you get off to it.
                            Due to the copious amounts of spit you used when sucking him off, his shaft is still somewhat slick.
                            Grow aroused, but don't cum from being fucked.
                            Man cums inside of you, you get let up, and are allowed to breathe again right as you were about to pass out.
                            Man thanks you and swims back to shore, him and his friends leave.
                            You leave and head home. It's too late to continue.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexPlay.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexLetHappen.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSexLetHappen(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preSexHappen;
    var changeController = ctrl.sexHappen;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The man fucks you while holding you underwater.
                            The flow of the river has washed away your spit. His unlubed dick hurts.
                            Ultimately pass out due to lack of air right as he finishes inside of you.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexLetHappen.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexClaw.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSexClaw(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverMouthHappenChoice.CLAW;
    var reqController = ctrl.mouthHappen;
    var changeController = ctrl.sexClaw;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Mangle the man's groin.
                            Swim away as he releases you.
                            His comrades hit you with a rock.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\sex\ForestRiverSexClaw.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\finish\ForestRiverMouthFinish.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverMouthFinish(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverMouthSuckChoice.FINISH;
    var reqController = ctrl.suck;
    var changeController = ctrl.mouthFinish;

    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = ctrl.homeSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Finish the man with your mouth.
                            Friends laugh at him.
                            He swims out of the water, grabs his clothes and the group disperses.
                            Too late to continue now.
                            Swim to the shore.
                            Head home.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\finish\ForestRiverMouthFinish.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\finish\ForestRiverMouthDoNot.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverMouthDoNot(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverMouthSuckChoice.DONOT;
    var reqController = ctrl.suck;
    var subController = ctrl.mouthDoNot;
    var changeController = ctrl.mouthDoNot;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverSexPlay(ctrl);
    var secondNext = ctrl.fragments.sexHappen;

    var firstChoice = ForestRiverMouthDoNotChoice.PLAY;
    var secondChoice = ForestRiverMouthDoNotChoice.HAPPEN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Pull back and get some air. Man turns you around, pushes you underwater again, and presses his dick against your tailhole/slit.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Play along</button>`;

        var tooltip = global.parser.parse(`You've been waiting for this moment ever since you saw the hunk of a human undress.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Let it happen</button>`;

        var tooltip = global.parser.parse(`The human's taking things one step too far, but you're powerless to stop him.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            ctrl.preSexHappen.continue();
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverMouthDoNotChoice = {
    PLAY: 1,
    HAPPEN: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\finish\ForestRiverMouthDoNot.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthSuck.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverMouthSuck(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverHandsSpreadChoice.SUCK;
    var reqController = ctrl.spread;
    var subController = ctrl.suck;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverMouthFinish(ctrl);
    var secondNext = new ForestRiverMouthDoNot(ctrl);

    var firstChoice = ForestRiverMouthSuckChoice.FINISH;
    var secondChoice = ForestRiverMouthSuckChoice.DONOT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Eagerly suck the guy off. He tries to push your head off of his cock.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Finish him</button>`;

        var tooltip = global.parser.parse(`Use your mouth to get the man off, so he [i]can't[/i] fuck you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Pull back</button>`;

        var tooltip = global.parser.parse(`Why would you want him to cum? The fun part hasn't even started yet.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverMouthSuckChoice = {
    FINISH: 1,
    DONOT: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthSuck.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthHappen.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverMouthHappen(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preMouthHappen;
    var subController = ctrl.mouthHappen;
    var changeController = ctrl.mouthHappen;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = ctrl.fragments.sexHappen;
    var secondNext = new ForestRiverSexClaw(ctrl);

    var firstChoice = ForestRiverMouthHappenChoice.HAPPEN;
    var secondChoice = ForestRiverMouthHappenChoice.CLAW;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Man spreads your jaws open and fucks your warm mouth.
                            After thoroughly pounding your face, he pulls you up out of the water, but only for second.
                            He turns you around, and promptly pushes you back down again, the tip of his member rubbing against your ass/cunt.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Let it happen</button>`;

        var tooltip = global.parser.parse(`If you struggle, he'll drown you to death. Let the man take you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Claw</button>`;

        var tooltip = global.parser.parse(`His groin is just within your reach. [b]Mangle[/b] it.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            ctrl.preSexHappen.continue();
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverMouthHappenChoice = {
    HAPPEN: 1,
    CLAW: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthHappen.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthBite.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverMouthBite(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverHandsStruggleChoice.BITE;
    var reqController = ctrl.struggle;
    var changeController = ctrl.bite;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Bite the man's dick off. River runs red with blood. Get hit with a rock as the man passes out.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\mouth\ForestRiverMouthBite.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsStruggle.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverHandsStruggle(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverHandsChoice.STRUGGLE;
    var reqController = ctrl.handsUp;
    var subController = ctrl.struggle;
    var changeController = ctrl.struggle;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = ctrl.fragments.mouthHappen;
    var secondNext = new ForestRiverMouthBite(ctrl);

    var firstChoice = ForestRiverHandsStruggleChoice.HAPPEN;
    var secondChoice = ForestRiverHandsStruggleChoice.BITE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Struggle against the man's grasp while he fingers your slit or your tailhole.
                            Man says the water is cold. It's up to you to heat him up.
                            Then he forces your head underneath the water.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Let it happen</button>`;

        var tooltip = global.parser.parse(`The men'll kill you if you fight back. Let the human have his way with your muzzle.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Bite</button>`;

        var tooltip = global.parser.parse(`Letting a sharp-teethed kobold near his groin was the last mistake the human'll ever make.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            ctrl.preMouthHappen.continue();
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverHandsStruggleChoice = {
    HAPPEN: 1,
    BITE: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsStruggle.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsSpread.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverHandsSpread(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverHandsChoice.SPREAD;
    var reqController = ctrl.handsUp;
    var subController = ctrl.spread;
    var changeController = ctrl.spread;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverMouthSuck(ctrl);
    var secondNext = ctrl.fragments.mouthHappen;

    var firstChoice = ForestRiverHandsSpreadChoice.SUCK;
    var secondChoice = ForestRiverHandsSpreadChoice.HAPPEN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Spread your legs and moan like a cheap whore while he fingers your slit or your tailhole.
                            Man says the water is cold. It's up to you to heat him up.
                            Then he forces your head underneath the water.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Suck it</button>`;

        var tooltip = global.parser.parse(`Do your best to please. The sooner this is over with, the faster you can get on with your travels.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Let it happen</button>`;

        var tooltip = global.parser.parse(`You never signed up for this! You're too fearful of the man to fight back, though.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            ctrl.preMouthHappen.continue();
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverHandsSpreadChoice = {
    SUCK: 1,
    HAPPEN: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsSpread.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsKick.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverHandsKick(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverHandsChoice.KICK;
    var reqController = ctrl.handsUp;
    var changeController = ctrl.kick;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Kick the man's face, break his nose, buddies hit you with a rock.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\action\ForestRiverHandsKick.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\ForestRiverHands.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverHands(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverFreezeChoice.HANDS;
    var reqController = ctrl.freeze;
    var subController = ctrl.handsUp;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new ForestRiverHandsSpread(ctrl);
    var secondNext =  new ForestRiverHandsStruggle(ctrl);
    var thirdNext =  new ForestRiverHandsKick(ctrl);

    var firstChoice = ForestRiverHandsChoice.SPREAD;
    var secondChoice = ForestRiverHandsChoice.STRUGGLE;
    var thirdChoice = ForestRiverHandsChoice.KICK;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Put up your hands, man wades over to you, grabs you by your wrists, and lifts you up out of the water.
                            If still dressed, he either tugs down your linen pants or reaches underneath your loincloth, and begins to fondle your slit/ass.
                            "If you play along, I won't even take that bag of coins around your neck."
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Spread</button>`;

        var tooltip = global.parser.parse(`Play along. Spread your legs. Be a good little kobold.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Struggle</button>`;

        var tooltip = global.parser.parse(`Fight against the human's grasp, but don't outright assault him.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Kick</button>`;

        var tooltip = global.parser.parse(`Kick him and make a run for it!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var ForestRiverHandsChoice = {
    SPREAD: 1,
    STRUGGLE: 2,
    KICK: 3
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\hands\ForestRiverHands.js

// scenes\ForestToVaranar\ForestRiver\swim\freeze\ForestRiverFreeze.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverFreeze(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimmingChoice.FREEZE;
    var reqController = ctrl.swimming;
    var subController = ctrl.freeze;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverHands(ctrl);
    var secondNext = new ForestRiverWeapon(ctrl);

    var firstChoice = ForestRiverFreezeChoice.HANDS;
    var secondChoice = ForestRiverFreezeChoice.WEAPON;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The guy with the slingshot looks like he has a pair of good eyes on him,
                            and the slinger, too, seems pretty experienced in the use of his weapon.
                            You don't [b]dare[/b] to move, lest they [b]pelt[/b] you with rocks.
                            Worse yet, if you run away, and the big dude gets his hands on you, he'd tear you limb from limb!
                            No, trying to swim away would not be the best thing to do right now.
                            There may be a way out of this yet, but you need to be [b]smart[/b] about it.
                        [/p]
                        [p]
                            You tread water in-place, keeping your head above the surface without moving.
                            Turning around, you witness the leader of the gang upping his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            You cast a pleading gaze up at the encroaching monster of a human, hoping to be granted some form of mercy.
                            But instead of pity, there is only [b]lust[/b] and [b]disdain[/b] in his eyes.
                            "[color=green]Hands up, lizard.[/color]"
                            he commands, eagerly licking his lips.
                            "[color=green]I don't want there to be any [b]surprises[/b].
                            And neither do [b]you[/b], if you want to leave this river alive.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} disabled>Hands up</button>`;

        var tooltip = global.parser.parse(`If you comply with his demands, he'll have no reason to hurt you. Right? [todo]Unavailable.[/todo]`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var weapon = ctrl.misc.weapon();
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 250px;">Reach for ${weapon ? `your weapon` : `a rock`}</button>`;

        var tooltip = global.parser.parse(`Like hell you're going to surrender to some human ruffian. If he wants a piece of you, let'em come get some.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 250px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverFreezeChoice = {
    HANDS: 1,
    WEAPON: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\freeze\ForestRiverFreeze.js

// scenes\ForestToVaranar\ForestRiver\swim\ForestRiverSwimming.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSwimming(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.swimming;
    var changeController = ctrl.swimming;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverKeep(ctrl);
    var secondNext = new ForestRiverFreeze(ctrl);

    var firstChoice = ForestRiverSwimmingChoice.KEEP;
    var secondChoice = ForestRiverSwimmingChoice.FREEZE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var stripped = ctrl.swim.get() === ForestRiverSwimChoice.STRIP;
        var toReturn = `[p]
                            You stride forwards, and enter the water properly.
                            In one step, your feet are immersed in the freezing liquid.
                            You shiver and grit your teeth, but you keep going.
                            Your shins go under, and then your loins become submerged,
                            the ice-cold liquid creeping into every crevice and orifice, chilling you to the very bone.
                            You take a moment to adapt to the temperature.
                            Then, you decide to take the plunge.
                        [/p]
                        [p]
                            Exhaling deeply, you squat down, [b]plunging[/b] your upper body into the ice-cold water.
                            Your entire frame trembles, your teeth chattering together, the temperature [b]far[/b] too low for a little lizard like you.
                            It's [b]so[/b] cold, it almost [b]burns[/b].
                            In a way, the frigid temperatures are sort of [i]rejuvenating[/i], the adrenaline flooding through your body making you feel truly [b]alive[/b].
                            But in another way, it's just [b]cold enough to kill[/b].
                            You can feel the tip of your tail starting to [b]freeze[/b].
                            You have to stay active, to keep the blood pumping throughout your body.
                            You need to keep moving.
                        [/p]
                        [p]
                            You lean forwards, and begin to [b]swim[/b] across the river, propelling yourself through the water with slow,
                            deliberate motions of your shaking limbs.
                            You're already breathing heavily, not from physical exertion, but from the sheer [b]frigidness[/b] of the liquid surrounding you.
                            It feels like your chest is being [b]constricted[/b] by the near-zero temperatures.
                            Your troubled breathing luckily lessens,
                            your respiratory system relaxing the more accustomed you grow to your new surroundings,
                            and the more active your body becomes.
                            Kobolds are nothing if not adept at adapting.
                        [/p]
                        [p]
                            The current isn't too bad, near the bank of the river.
                            But the further out you get into the water, the stronger it becomes.
                            Almost a quarter of your way across, as you get into the [b]deep[/b] part of the river, the water's pull tangibly intensifies.
                            While it's nothing you can't fight,
                            the current still makes what was [i]supposed[/i] to be a relaxing swim into more of a [b]struggle[/b] to make it across.
                        [/p]
                        [p]
                            About halfway through your arduous journey, a large rock a little upstream, underneath the bridge, lessens the flowing water's constant pull.
                            You consider taking a slight [i]breather[/i] from swimming,
                            but the sun dropping lower and lower serves as a constant, stern reminder of your strict schedule
                            -- which has already been disrupted by having to swim instead of walking across the bridge.
                            You're a lot quicker on land than you are in the water.
                            Come to think of it, you're pretty much a [b]sitting duck[/b] for anyone with a keen eye and a ranged weapon.
                            Right as that thought crosses your mind, you hear noise behind you, over the soft sounds of the rippling flow of the river.
                            Branches snapping, foliage being pushed aside, [b]footsteps[/b].
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hold it right there, kobold![/color]"
                            [/big]
                        [/p]
                        [p]
                            [b]Oh no[/b].
                            Your heart sinks.
                            A knot forms in your stomach.
                            For a moment, you fear it may be the transport guards chasing after you.
                            A quick glance backwards disconfirms your worst fears.
                            Humans.
                            Three of them.
                            They don't look like the group you saw escorting the caravan.
                            They're less well dressed, clad in patched together, obnoxiously-yellow dyed attire.
                            Bandits?
                            Albeit not very subtle ones.
                        [/p]
                        [p]
                            One of the men is armed with a slingshot, loaded with a sharp, pointy rock, aimed directly at [b]you[/b].
                            Another ${stripped ? `grabs your discarded clothing,
                            giving it a crude [b]sniff[/b] before [b]tearing[/b] the flimsy fabric apart. Then, he` : ``} brandishes a regular sling,
                            which he swings in a rotary fashion, preparing to let loose a more [i]blunt[/i] piece of stone.
                            The third, the most muscular of the group, wields a large, wooden club, bigger than your head.
                        [/p]
                        [p]
                            Definitely not a [i]refined[/i] group of thugs.
                            Textbook definition of a gang of [b]ruffians[/b].
                            Crude weapons, crude attire, crude [b]attitude[/b].
                            Noticing that he's caught your attention, the brawny member of the group calls out to you once more.
                            "[color=green]This is [b]our[/b] part of the river.
                            If you want to cross here, you're going to have to pay us a [b]fine[/b].[/color]"
                            The human takes off his shirt, exposing his ripped and muscular upper body.
                            He looks like he could absolutely [b]tear[/b] you in [b]half[/b].
                        [/p]
                        [p]
                            A fine?
                            You [i]guess[/i] you could spare like maybe five or ten coins?
                            The bandit leader isn't done talking, however.
                            "[color=green]And since your kind isn't known for being [b]rich[/b], I'll settle for your [b]body[/b] instead.[/color]"
                            Wait, what?
                            The human tosses his weapon to the side, and lowers his pants, his large, cut, half-erect member coming into view.
                            He's [b]hung[/b] like a horse!
                        [/p]
                        [p]
                            "[color=cyan]Move, and you [b]die[/b].[/color]" threatens the slingshot-wielding thug.
                            The sling-armed human nods in agreement.
                            Their leader, meanwhile, [b]strides[/b] into the water, completely unfazed by the temperature.
                            Do you attempt to swim away, or do you remain in place?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Keep going</button>`;

        var tooltip = global.parser.parse(`Get the hell out of here!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 170px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Freeze</button>`;

        var tooltip = global.parser.parse(`Remain in place. Maybe the man'll take some coins instead.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverSwimmingChoice = {
    KEEP: 1,
    FREEZE: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\ForestRiverSwimming.js

// scenes\ForestToVaranar\ForestRiver\swim\ForestRiverStrip.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverStrip(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimChoice.STRIP;
    var reqController = ctrl.swim;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.swimming;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverStripped = true;
        var male = ctrl.misc.dick();
        var loincloth = ctrl.misc.underwear();
        var loinclothTooltip = global.kobold.inventory.createItemWithTooltip(loincloth);
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var bra = ctrl.misc.bra();
        var braTooltip = global.kobold.inventory.createItemWithTooltip(bra);
        var toReturn = `[p]
                            You're not going to swim with clothes on.
                            That'd be [b]dumb[/b].
                            They'd weigh you down, and you'd freeze your butt off when coming out of the water.
                            Well, you're going to be chilled to the bone either way,
                            but if you skinnydip, at least you won't be wet for the entire remainder of the way to Varanar.
                            You can buy some new [i]rags[/i] when you get to the city proper.
                            Ten gold more or less won't make or break your deal with the Rat Clan.
                            Or so you hope.
                        [/p]
                        [p]
                            With a sigh, you lower your ${male ? `${loinclothTooltip}` : `${pantsTooltip}, and take off your ${braTooltip}`},
                            leaving you fully naked.
                            The cold breeze rolling over your nether-scales feels kind of [i]liberating[/i].
                            Like you've shed the last remnants of your old life.
                            Today is the beginning of a new you.
                            A kobold that takes [b]risks[/b], instead of playing things [b]safe[/b].
                            You're turning over a new leaf.
                            You're going to make it [b]big[/b]!
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\ForestRiverStrip.js

// scenes\ForestToVaranar\ForestRiver\swim\ForestRiverNoStrip.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverNoStrip(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimChoice.NOSTRIP;
    var reqController = ctrl.swim;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.swimming;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Stripping?
                            What are you, some kind of [b]wimp[/b] that can't swim with a bit of extra baggage?
                            You don't fear the cold.
                            And even if you did, you'd keep your clothes on to [b]spite[/b] Mother Nature.
                            Today is the beginning of a new you.
                            A kobold that takes [b]risks[/b], instead of playing things [b]safe[/b].
                            You're turning over a new leaf, and you're not going to start by [b]ditching[/b] your clothes in the middle of [b]nowhere[/b].
                        [/p]
                        [p]
                            Besides, you're headed for the capital of the humans.
                            You [b]don't[/b] want to go there naked.
                            You've heard [i]stories[/i] of the things they do to kobolds there.
                            While you won't be [i]spared[/i] because of your clothing,
                            you reckon it'll go a long way in preserving your dignity.
                            Plus, after your clothes have dried, they'll help to keep you warm.
                            It's always coldest right before dawn.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\ForestToVaranar\ForestRiver\swim\ForestRiverNoStrip.js

// scenes\ForestToVaranar\ForestRiver\swim\ForestRiverSwim.js

/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverSwim(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverArrivalChoice.SWIM;
    var reqController = ctrl.arrival;
    var subController = ctrl.swim;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverStrip(ctrl);
    var secondNext = new ForestRiverNoStrip(ctrl);

    var firstChoice = ForestRiverSwimChoice.STRIP;
    var secondChoice = ForestRiverSwimChoice.NOSTRIP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.dick();
        var loincloth = ctrl.misc.underwear();
        var loinclothTooltip = global.kobold.inventory.createItemWithTooltip(loincloth);
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var bra = ctrl.misc.bra();
        var braTooltip = global.kobold.inventory.createItemWithTooltip(bra);
        var toReturn = `[p]
                            You're not going to risk crossing the bridge.
                            It's too dangerous, and you don't feel comfortable putting your life in the hands of a poorly-built,
                            rotten, ramshackle construct!
                            Your next best option is to swim across.
                            You know you can make it, and while you've gotten [b]plenty[/b] of [i]exercise[/i] these past few days,
                            it'll be [b]nice[/b] to practice swimming for a bit, instead of walking and running away and jumping and climbing and crawling all the time.
                        [/p]
                        [p]
                            You walk up to the edge of the water, and dip your claws into the river.
                            [b]Ice cold[/b], as expected.
                            It's not like you intend to [i]linger[/i] in it, and it'll certainly [i]feel[/i] a lot warmer while you're swimming.
                            You've swum across the river before.
                            Never during the winter, and never this [i]late[/i], but still.
                            You're certain you'll be fine.
                        [/p]
                        [p]
                            If you keep your
                            ${male ? loinclothTooltip : pantsTooltip + ` and ` + braTooltip} on, then ${male ? `it` : `they`}'ll get soaked.
                            The water'll roll off of your scales with ease, but even if you wring it out, your clothing tends to remain wet for a long time still.
                            Wearing garments damp with freezing water on an evening as chilly as this one, is just [b]asking[/b] for trouble.
                            You could get [b]sick[/b] or even [b]freeze[/b] to death, if you don't make it somewhere warm before long.
                        [/p]
                        [p]
                            Keeping your clothes on will also making swimming a teensy bit harder, although you doubt that'll be the straw that breaks the kobold's back.
                            Plus, your kind isn't so [i]strict[/i] on clothing.
                            Sure, [i]most[/i] of you wear some scarce apparel, but a lot of kobolds tend to run around [b]naked[/b].
                            If you leave your clothes here, it's likely you'll never see them again, but that's not necessarily a big deal.
                            For once in your life, you have enough gold to buy yourself a new attire!
                            Although you shouldn't get ahead of yourself.
                            You still have a debt to pay off, after all.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Strip</button>`;

        var tooltip = global.parser.parse(`Your clothing will make it harder to swim.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 165px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Don't strip</button>`;

        var tooltip = global.parser.parse(`Waste not, want not.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverSwimChoice = {
    STRIP: 1,
    NOSTRIP: 2
};

// END scenes\ForestToVaranar\ForestRiver\swim\ForestRiverSwim.js

// scenes\ForestToVaranar\ForestRiver\bridge\ForestRiverBridge.js

/**
 * Information about the class.
 */
function ForestRiverBridge() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}

// END scenes\ForestToVaranar\ForestRiver\bridge\ForestRiverBridge.js

// scenes\ForestToVaranar\ForestRiver\arrival\ForestRiverArrival.js

/**
 * Arrival section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverSwim(ctrl);
    var secondNext = new ForestRiverBridge(ctrl);

    var firstChoice = ForestRiverArrivalChoice.SWIM;
    var secondChoice = ForestRiverArrivalChoice.BRIDGE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After a solid half-hour of high-paced marching through the forest,
                            you arrive at the forgotten river crossing.
                            The trek took quite a bit longer than you thought it would.
                            The sun's already starting its descent.
                            You don't think it'll be light out for much longer.
                            While you'd love to rest your weary feet for a bit, you simply don't have the time.
                            You step out onto the riverbank, and inspect the tiny bridge while you still can.
                        [/p]
                        [p]
                            The old, wooden construct is [b]far[/b] more dilapidated than it was the last time you were here.
                            It's only [b]barely[/b] still standing, several of the rotting logs supporting it having visible cracks in them,
                            one of the load-bearing poles broken completely.
                            As a small gust of wind picks up, the bridge sways back and forth ominously, like it's about to [b]break[/b] there and then.
                            But, despite looking like it's long-overdue a one-way trip into the river, it holds.
                        [/p]
                        [p]
                            The decrepit state of the bridge has you second-guessing your plans.
                            You'd hoped to find it in a bit better condition, but it seems time has taken its toll on the unmaintained structure.
                            A shame, you have some fond memories escaping from pitchfork-wielding mobs across it.
                            Those farmers never did find out how it was that you kept escaping their clutches.
                        [/p]
                        [p]
                            Humans, a bunch of [i]idiots[/i], the lot of them.
                            They may be [b]bigger[/b] and [b]stronger[/b] and [b]smarter[/b] than you are,
                            but you haven't met a single one able to match your thieving wit!
                            Then again, you doubt the poor dirt farmers that inhabit the hamlet outside of the city are as clever as the rest of their kind.
                            You're certain that the people of Varanar will be a lot quicker to see through your hare-brained schemes.
                        [/p]
                        [p]
                            Snapping out of your reminiscing, you focus on the task at hand.
                            The easy river-crossing you were counting on is [b]not[/b] a part of the hand you were dealt.
                            You [i]could[/i] still risk going across bridge, but that would be [b]very[/b] unsafe, to say the least.
                            You can already picture yourself falling through the flimsy wood.
                            Or maybe the entire thing'll give way, sending you crashing down into the rocky river.
                            If you're lucky, you'll live to tell the tale.
                            If not, you could break your neck, drown underneath debris, or crack your skull by hitting your head against a rock on the way down.
                            And you're not very keen on becoming a gold-laden skeletal corpse for a lucky adventurer to stumble upon.
                        [/p]
                        [p]
                            But you don't want a single, small setback like this to be the end of your expedited journey to the capital.
                            You [b]aren't[/b] going home without at least [b]trying[/b] to cross.
                            The bridge is risky, but there are [b]alternatives[/b].
                            Alternatives like [b]swimming[/b] to the other side.
                            The current is manageable in this area.
                            The water's probably freezing cold,
                            and the river's pretty wide,
                            but you think you [i]should[/i] be able to manage to swim across without too much trouble.
                            It's either that, or brave the bridge.
                            Time to pick your poison.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Swim</button>`;

        var tooltip = global.parser.parse(`Swim across the river. It's not [i]that[/i] wide.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} disabled>Bridge</button>`;

        var tooltip = global.parser.parse(`Cross the bridge. [todo]Unavailable.[/todo]`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.applyTheme("forest");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        //part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        //secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        //registerSecondListener();
    };
}

var ForestRiverArrivalChoice = {
    SWIM: 1,
    BRIDGE: 2
};

// END scenes\ForestToVaranar\ForestRiver\arrival\ForestRiverArrival.js

// scenes\ForestToVaranar\ForestRiver\ForestRiverController.js

/**
 * Controller for the Forest River scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestRiverController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "VaranarRiver";
    this.nextFolderName = "ForestToVaranar";

    this.homeSceneReady = true;
    this.homeSceneName = "Home";
    this.homeFolderName = "";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");

    this.swim = new ChoiceController(id, "swim");
    this.swimming = new ChangeController(id, "swimming", function () {
        global.kobold.status.physical.increase(5, "Freezing water");
        global.kobold.status.physical.decrease(2, "Cold");
        global.kobold.status.mental.decrease(6, "Impending rape");
        global.kobold.status.stamina.decrease(6, "Swimming");
        if (that.swim.get() === ForestRiverSwimChoice.STRIP) {
            global.kobold.inventory.equipment.strip(SlotEnum.BRA);
            global.kobold.inventory.equipment.strip(SlotEnum.UNDERWEAR);
            global.kobold.inventory.equipment.strip(SlotEnum.PANTS);
        }
    }, function () {
        var notes = [
            new Change("Freezing water", "Health", +5),
            new Change("Cold", "Health", -2),
            new Change("Bandits", "Sanity", -3),
            new Change("Impending rape", "Sanity", -3),
            new Change("Swimming", "Stamina", -6)
        ];

        if (that.swim.get() === ForestRiverSwimChoice.STRIP) {
            var bra = that.misc.bra();
            if (bra) {
                notes.push(new Change("Stripped bra", global.kobold.inventory.createItemWithTooltip(bra, true), -1));
            }
            var underwear = that.misc.underwear();
            if (underwear) {
                notes.push(new Change("Stripped underwear", global.kobold.inventory.createItemWithTooltip(underwear, true), -1));
            }
            var pants = that.misc.pants();
            if (pants) {
                notes.push(new Change("Stripped pants", global.kobold.inventory.createItemWithTooltip(pants, true), -1));
            }
        }

        return global.ui.change.buildNotification(notes);
    });

    this.keepGoing = new ChoiceController(id, "keepGoing");
    this.otherSide = new ChangeController(id, "otherSide", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(8, "Surrounded by bandits");
        global.kobold.status.stamina.decrease(8, "Fast swimming");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Kicked", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Near-misses", "Sanity", -4),
            new Change("Surrounded", "Sanity", -4),
            new Change("Fast swimming", "Stamina", -8)
        ]);
    });
    this.upstreamSuccess = new ChangeController(id, "upstreamSuccess", function () {
        global.kobold.status.physical.decrease(6, "Drowning");
        global.kobold.status.mental.increase(4, "Back on dry land");
        global.kobold.status.stamina.decrease(6, "Made it ashore");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Drowning", "Health", -4),
            new Change("Successful escape", "Sanity", +6),
            new Change("Almost drowned", "Sanity", -4),
            new Change("Back on dry land", "Sanity", +2),
            new Change("Underwater swimming", "Stamina", -4),
            new Change("Drowning", "Stamina", -4),
            new Change("Made it ashore", "Stamina", +2)
        ]);
    });
    this.upstreamFail = new ChangeController(id, "upstreamFail", function () {
        global.kobold.status.physical.decrease(21, "Knocked out");
        global.kobold.status.mental.decrease(8, "Almost drowned");
        global.kobold.status.stamina.decrease(8, "Drowning");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Drowning", "Health", -4),
            new Change("Hit by rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Failed to escape", "Sanity", -4),
            new Change("Almost drowned", "Sanity", -4),
            new Change("Underwater swimming", "Stamina", -4),
            new Change("Drowning", "Stamina", -4)
        ]);
    });
    this.downstreamSuccess = new ChangeController(id, "downstreamSuccess", function () {
        global.kobold.status.physical.decrease(2, "Freezing cold");
        global.kobold.status.mental.increase(4, "Back on dry land");
        global.kobold.status.stamina.decrease(6, "Made it ashore");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Successful escape", "Sanity", +6),
            new Change("Heart-racing dodging", "Sanity", -4),
            new Change("Back on dry land", "Sanity", +2),
            new Change("Current-assisted swimming", "Stamina", -4),
            new Change("Dodging rocks", "Stamina", -4),
            new Change("Made it ashore", "Stamina", +2)
        ]);
    });
    this.downstreamFail = new ChangeController(id, "downstreamFail", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(1, "Dodging rocks");
        global.kobold.status.stamina.decrease(8, "Dodging rocks");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Hit rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Escaped", "Sanity", +3),
            new Change("Heart-racing dodging", "Sanity", -4),
            new Change("Current-assisted swimming", "Stamina", -4),
            new Change("Dodging rocks", "Stamina", -4)
        ]);
    });

    this.freeze = new ChoiceController(id, "freeze");

    this.weapon = new ChoiceController(id, "weapon");
    this.strike = new ChangeController(id, "strike", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(4, "Blinded by pride");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Hit by rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Triumph", "Sanity", +3),
            new Change("Pride", "Sanity", +3),
            new Change("Blinded by pride", "Sanity", -10)
        ]);
    });
    this.reconsider = new ChangeController(id, "reconsider", function () {
        global.kobold.inventory.coins = global.kobold.inventory.coins - that.misc.gold();
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(17, "Blinded by pride");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Punched in the face", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Treated like a child", "Sanity", -4),
            new Change("Blinded by rage", "Sanity", -10),
            new Change("Fucked up bigtime", "Sanity", -3),
            new Change("Gold taken", "Gold", -that.misc.gold())
        ]);
    });

    this.handsUp = new ChoiceController(id, "handsUp");

    this.spread = new ChangeController(id, "spread", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.struggle = new ChangeController(id, "struggle", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kick = new ChangeController(id, "kick", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.preMouthHappen = new ContinueController(id, "preMouthHappen");

    this.suck = new ChoiceController(id, "suck");

    this.mouthHappen = new ChangeController(id, "mouthHappen", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.bite = new ChangeController(id, "bite", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.mouthFinish = new ChangeController(id, "mouthFinish", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.mouthDoNot = new ChangeController(id, "mouthDoNot", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.preSexHappen = new ContinueController(id, "preSexHappen");

    this.sexHappen = new ChangeController(id, "sexHappen", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.sexPlay = new ChangeController(id, "sexPlay", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.sexClaw = new ChangeController(id, "sexClaw", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });


    /**this.secondChoice = {
     DECLINE: 1,
     ACCEPT: 2
     };*/

    this.fragments = {};
    this.fragments.sexHappen = new ForestRiverSexLetHappen(this);
    this.fragments.mouthHappen = new ForestRiverMouthHappen(this);
    this.fragments.swimming = new ForestRiverSwimming(this);

    this.bgm = new AudioController(id, "res/audio/effects/river.mp3", 100);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}

// END scenes\ForestToVaranar\ForestRiver\ForestRiverController.js

// scenes\ForestToVaranar\ForestRiver\ForestRiver.js

/**
 * River in the forest.
 */
function ForestRiver() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "ForestRiver";
    var sceneName = "Forest, River Crossing";
    var sceneSubfolder = "ForestToVaranar";
    var ctrl = new ForestRiverController(sceneId, this);
    var arrival = new ForestRiverArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]Forest[/t]`);
        tab += global.parser.parse(`[st]River crossing[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new ForestRiver();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\ForestToVaranar\ForestRiver\ForestRiver.js



// END SCENE ForestRiver

